import { observable, computed, action } from 'mobx'

export class TimeCellModel {
    @observable index = ''
    @observable number = ''
    manager = null
    @computed
    get selected() {
        return this.manager.selectedTimeModel == this
    }
    @computed
    get timeTag() {
        if (this.index % 2 == 0) {
            return this.prefixInteger(this.index / 2, 2) + ':00'
        }
        else {
            return this.prefixInteger(Math.floor(this.index / 2), 2) + ':30'
        }
    }
    @computed
    get numberTag() {
        if (this.number == 0) {
            return ' (已满员)'
        }
        else {
            return ' (剩余' + this.number + '人)'
        }
    }
    @action
    select = () => {
        this.manager.selectedTimeModel = this
    }
    /*
    *index 顺序位置 0~ 48
    *number 该时段的剩余人数
    *manger 管理类
    */
    constructor(index, number, manager) {
        this.index = index
        this.number = number
        this.manager = manager
    }
    //补位0
    prefixInteger = (num, n) => {
        return (Array(n).join(0) + num).slice(-n)
    }
}

export class ClassroomModel {
    @observable id = ''
    @observable name = ''
    manager = null
    constructor(id, name, manager) {
        this.id = id
        this.name = name
        this.manager = manager
    }
    @computed
    get selected() {
        return this.manager.selectedClassroom == this
    }
    @action
    select = () => {
        this.manager.selectedClassroom = this
    }
}

export class GradeModel {
    /**
     * 学年id
     * 
     * @memberof GradeModel
     */
    @observable id = ''

    /**
     * 学年名字
     * 
     * @memberof GradeModel
     */

    @observable name = ''
    /**
     * 父管理类
     * 
     * @memberof GradeModel
     */
    
    manager = null

    constructor(id, name, manager) {
        this.id = id
        this.name = name
        this.manager = manager
    }
    /**
     * 是否为选定
     * 
     * @readonly
     * @memberof GradeModel
     */
    @computed
    get selected() {
        return this.manager.selectedGrade == this
    }
    /**
     * 设置为选定
     * 
     * @memberof GradeModel
     */
    @action
    select = () => {
        this.manager.selectedGrade = this
    }
}