import { observable, action, computed } from 'mobx'
import { CzbApi } from '../model'
import { NetStore, StorageStore } from '../store'

class Content {

    @observable bannerData = null
    @observable noCache = false
    /**
     * 获取首页Banner
     * advType 平台类型（必传：1，成长保手机APP；3，成长保PC网站；4，成长保移动网站；5，思维喵PC网站；6，思维喵移动网站）
     * @memberof Content
     */
    fetchBanner = () => {
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.homeADV, { advType: 1, pageNum: 1, pageSize: 10 })
                .then(response => {
                    // console.log(response, 'fetchBanner-=-=--=');
                    // this.bannerData = response.result.advList
                    resolve(response.data.advList)
                    StorageStore.save('bannerData', response.data.advList)
                })
                .catch(err => {
                    console.log(err)
                    if (!this.noCache) {
                      this.loadBannerInfo()
                    }
                    reject(err)
                })
        })
    }
    /**
     * 从沙盒读取用户信息
     * return promise
     * @memberof ContentStore
     */
    @action
    loadBannerInfo = () => {
        return new Promise((resolve, reject) => {
            StorageStore.load('bannerData', () => { }, false)
                .then(response => {
                    this.bannerData = response
                    this.noCache = false
                    resolve(response)
                })
                .catch(error => {
                    this.noCache = true
                    reject(error)
                })
        })
    }

}
export let ContentStore = new Content
