import { observable, action } from 'mobx'
import { CzbApi } from '../model'
import { NetStore, ShareStore } from '../store'

class Evaluate {

    @observable evaluationTagDataSource = [] //原始标签数据

    @observable isEvaluated = false
    @observable evaluationTagScore = null //用户维度评分（星星数量）
    @observable evaluationContent = null //用户评价内容
    @observable isShowEvaluateBtn = false

    /*
    * 学生端获取评论标签接口
    * */
    getEvaluationTagDataSource = () => {
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.GetEvaluationTagDataSource)
                .then(response => {
                    console.log(response, 'getEvaluationTagDataSource-=-=');
                    const paramArray = response.data
                    this.evaluationTagDataSource = paramArray.map((value, index) => {
                        const { id, tagname: tag, star } = value
                        return {
                            id,
                            tag,
                            star: 0,
                        }
                    })
                    resolve(response)
                })
                .catch(error => {
                    reject(error)
                })
        })
    }

    /*
    * 查询是否已评价课程
    * courseID：课程id
    * userID：用户id
    * */
    getIsEvaluated = (classroomID, userID) => {
        let url = CzbApi.GetIsEvaluated
        let getData = {
            roomId: classroomID,
            operater: userID
        }
        return new Promise((resolve, reject) => {
            NetStore.fetch(url, null, getData)
                .then(response => {
                    // this.isEvaluated = true
                    console.log(response, getData, 'getIsEvaluated-----');
                    if (response.data) {
                      this.isEvaluated = true
                    } else{
                      this.isEvaluated = false
                    }
                    resolve(response)
                })
                .catch(error => {
                    // this.isEvaluated = false
                    reject(error)
                })
        })
    }

    /*
    * 获取学生对课程的评价
    * courseID: 课程id
    * userID: 用户id
    * */
    getEvaluation = (classroomID, userID) => {
        let url = CzbApi.GetEvaluation
        let getData = {
            roomId: classroomID,
            operater: userID
        }
        return new Promise((resolve, reject) => {
            NetStore.fetch(url, null, getData)
                .then(response => {
                    // console.log(response, getData, 'getEvaluation=====');
                    if (response.code == 200 && response.data.id) {
                        this.isEvaluated = true
                        this.evaluationContent = response.data.evaluation || ''
                        this.evaluationTagScore = response.data.recordlist || ''
                    }
                    else {
                        this.isEvaluated = false
                        this.evaluationContent = null
                        this.evaluationTagScore = null
                    }
                    resolve(response)
                })
                .catch(error => {
                    this.isEvaluated = false
                    this.evaluationContent = null
                    this.evaluationTagScore = null
                    reject(error)
                })
        })
    }


    /*
    * 提交课程评价
    * courseID：课程ID
    * userID：用户id
    * tagScore：维度评分
    * content：评价内容
    * */
    commitEvaluation = (classroomID, userID, tagScore, content, courseType) => {
        return new Promise((resolve, reject) => {
            let data = {
                // "classid": courseID,
                // "operater": userID,
                // "remark": 2, //1为老师，2为学生
                // "studentid": userID,
                // "recordlist": tagScore,
                // "evaluation": content
                roomId: classroomID,
                operater: userID,
                studentid: userID,
                assessType: courseType,
                remark: 2,//1为老师，2为学生
                evaluation: content,
                recordlist: tagScore,
            }
            NetStore.fetch(CzbApi.CommitEvaluation, data)
                .then(response => {
                    console.log(response, data, 'commitEvaluation-----');
                    if (response.code != 200) {
                      return reject(response)
                    }
                    resolve(response)
                })
                .catch(error => {
                    reject(error)
                })
        })
    }

    /**
     * 判断是否显示评价按钮
     * 以课程结束前三分钟为是否显示依据
     * courseID：课程id
     * userID：用户id
     * alertTimestamp：弹出时间
     *
     * @memberof Evaluate
     */
    @action
    configEvaluateBtn = async (classroomID, userID, alertTimestamp) => {
        try {
            const res = await this.getIsEvaluated(classroomID, userID)
            if (!res.data) {
                await ShareStore.fetchServerTime()
                if (ShareStore.serverTimeNow <= alertTimestamp) {
                    this.timer = setTimeout(
                        () => {
                            this.isShowEvaluateBtn = true
                            this.getEvaluationTagDataSource()
                        },
                        (alertTimestamp - ShareStore.serverTimeNow)
                    )
                }
                else {
                    this.isShowEvaluateBtn = true
                    this.getEvaluationTagDataSource()
                }
            }
        } catch (e) {
            console.log(e)
        }
    }
}

export const EvaluateStore = new Evaluate
