import { CzbApi, CzbVideoType } from '../model'
import { Store } from '../Store'
import { NetStore, StorageStore, UserStore } from '../store'
import { action, observable, computed } from 'mobx'

class Home {

// 首页视频数组
  @observable courseVideoList = []

  @observable freeVideoClass = []
  @observable isRefreshFinish = false

//   @observable videoListCourseData = null
  @observable noCache = false
//   @observable videoListFreeData = null
  @observable dynamicTestUrl = null
  @observable pptUrl = null


  @action
  getDynamicTest = () => {
    this.pptUrl = CzbApi.kDynamicTest + `?token=${UserStore.token}&vsFrom=${Store.vsFrom}&userId=${UserStore.id}&userName=${UserStore.name}`
}

@action
fetchIsRefresh=(isRefresh) =>{
    this.isRefreshFinish = isRefresh
}

// 分类类型（pad宣传视频：padAd，专注力训练课：zzl，开课视频：kk，数理逻辑训练课：sl）
@action
fetchRecommendVideoListByHome = (typeNo = `padAd`) => {

    const query = {
        typeNo
    }
    return new Promise((resolve, reject) => {
        NetStore.fetch(`${CzbApi.kHomeVideoAd}?typeNo=${typeNo}`, null, null)
            .then((response) => {
                resolve(response)
            })
            .catch((error) => {
                reject(error)
            })
    })
}


  @action
  fetchVideoListByHome = (videoType) => {
    const query = {
        videoType: videoType, // 0,精品视频；1，成长视频
      }
      return new Promise((resolve,reject) => {
          NetStore.fetch(CzbApi.kFetchVideoListByHome,null,query)
            .then(response => {
                console.log(response, query, 'fetchVideoListByHome');
                if (videoType === 0){
                    this.courseVideoList = response.data
                    // boutqiue cache
                    StorageStore.save(CzbVideoType.BOUTIQUE, this.courseVideoList)
                }else {
                    this.freeVideoClass = response.data
                    StorageStore.save(CzbVideoType.FREE, this.freeVideoClass)
                }
                this.isRefreshFinish = true
                resolve(response.data)
            })
            .catch(error => {
                if (!this.noCache) {
                    this.loadVideoListCourseInfo()
                    this.loadVideoListFreeInfo()
                  }
                  reject(error)
                  this.isRefreshFinish = true
              })
      })
  }

   /**
     * 从沙盒读取用户信息
     * return promise
     * @memberof HomeStore
     */
    @action
    loadVideoListCourseInfo = () => {
        return new Promise((resolve, reject) => {
            StorageStore.load(CzbVideoType.BOUTIQUE, () => { }, false)
                .then(response => {
                    this.courseVideoList = response
                    this.noCache = false
                    resolve(response)
                })
                .catch(error => {
                    this.noCache = true
                    reject(error)
                })
        })
    }

    @action
    loadVideoListFreeInfo = () => {
        return new Promise((resolve, reject) => {
            StorageStore.load(CzbVideoType.FREE, () => { }, false)
                .then(response => {
                    this.freeVideoClass = response
                    this.noCache = false
                    resolve(response)
                })
                .catch(error => {
                    this.noCache = true
                    reject(error)
                })
        })
    }


}

export let HomeStore = new Home
