import { observable, action } from 'mobx'
import { CzbApi } from '../model'
import { NetStore, UserStore ,Store} from "react-native-czb"

class Homework {

    @observable homework = null
    @observable homeWorkStatus = 0 //未读
    @observable homeWorkTitle = '' // 作业title
    @observable homeWorkUrl = ''
    @observable isDynamicHomeWork = false // 动态作业是否绑定

    /**
     * Newapi
     * @desc 获取家庭作业 这里的作业是静态课件
     * @param arrangingId 用户排课记录唯一标识 这里可以用courseID传入
     * */
    @action
    fetchStaticHomework = (arrangingId,page = 1, size = 100) =>{
        let getData = {
            arrangingId:arrangingId,
            size:size,
            page:page
        }
        let url = CzbApi.GetHomework;
        return new Promise((resolve,reject)=>{
            NetStore.fetch(url, null, getData).then(response => {
                console.log('FinishedCourse','fetchStaticHomework110',response);
                if(response.code == 200){
                    this.resolveStaticHomework(response.data)
                    resolve(response);
                }else {
                    throw response
                }
            }).catch(error=>{
                reject(error)
                console.log('FinishedCourse','fetchStaticHomework',error)
            })
        })
    }

    /**
     * Newapi
     * @desc 用于解决静态家庭作业
     * @param result 请求静态家庭作业结果
     * */
    resolveStaticHomework = (result)=>{
        const {status,total,homeWorks} = result;
        this.homeWorkStatus = status;
        this.homework = homeWorks.slice().map(value=>value.pptUrl);
        console.log('FinishedCourse','resolveStaticHomework',this.homeWorkStatus,this.homework);
    }


    /**
     * 获取动态课件作业
     * @param pptId 课件id
     * @param roomId教室id
     * @param classId 班级ID
     * */
    @action
    fetchDynamicHomeWork = (pptId,roomId,classId)=>{
        this.homeWorkUrl = CzbApi.GetDynamicHomeWork + `?token=${UserStore.token}&userType=${1}&vsFrom=${Store.vsFrom}&cwId=${pptId}&userId=${UserStore.id}&userName=${UserStore.name}&roomId=${roomId}&arrangingId=${classId}`
    }

    /**
     * 获取动态课件作业完成状态
     * @param arrangingId 预约ID(courseID)
     * */
    fetchDynamicHomeWorkFinishState = (arrangingId)=>{
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kIsFinishedDynamicHomeWork, null, {
                arrangingId:arrangingId
            })
                .then(response => {
                    console.log('fetchDynamicHomeWorkFinishState',response);
                    const {code,data} = response;
                    if(code == 200){
                        this.homeWorkStatus = data;
                        resolve(response)
                    }else{
                        throw response;
                    }
                })
                .catch(error => {
                    this.homeWorkStatus = 0
                    reject(error)
                })
        })
    }

    /**
     * @desc 完成静态课件作业
     * @param arrangingId 相当于以前的courseID
     * */
    @action
    commitStaticHomework = (arrangingId)=>{
        let getData = {
            arrangingId:arrangingId
        }
        let url = CzbApi.kIsFinishedHomework
        return new Promise((resolve, reject) => {
            NetStore.fetch(url, null, getData)
                .then(response => {
                    this.homeWorkStatus = 1 //已完成
                    resolve(response)
                })
                .catch(error => {
                    this.homeWorkStatus = 0
                    reject(error)
                })
        })
    }

    /**
     * 课后作业已读未读功能
     * classId  课程id
     * userId
     * classType 课程类型
     * return promise
     * @memberof ReportStore
     */
    @action
    commitFinishedHomework = (courseID, courseType) => {
        this.commitStaticHomework(courseID)
    }


    @action
    clearHomework = () => {
        this.homework = null
        this.homeWorkStatus = 0
        this.homeWorkTitle = ''
        this.homeWorkUrl = ''
        this.isDynamicHomeWork = false
    }
}

export let HomeworkStore = new Homework
