import { observable, action } from 'mobx'
import { NetStore, UserStore, StorageStore } from '../store'
import { CzbApi } from '../model'
import { Store } from '../Store'

class Hour {

    @observable consumeHistory = [] //消耗课时记录
    @observable chargeHistory = [] //充值课时记录
    @observable allHistory = [] // 全部课时记录

    @observable officalHour = 0 //正式课时
    @observable experienceHour = 0 //体验课时
    @observable iapHour = 0 //内购课时

    /**
     * 获取用户课时数量
     * return promise
     *
     * @memberof HourStore
     */
    @action
    fetchCourseHour = () => {
        let tempTotal = 0;
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.GetCourseHour, null)
                .then(response => {
                    const leftHours = response.data
                    leftHours.map((value, index) => {
                        let { hourTypeCode: hourTypeCode, hourTypeName: hourTypeName, surplusQty: leftHour} = value
                        if (hourTypeCode != "EXPERIENCE" && hourTypeCode != 'VIDEO_GIFT') {
                            tempTotal += leftHour;
                            this.officalHour = tempTotal
                        }
                        else if (hourTypeCode == "EXPERIENCE") {
                            this.experienceHour = leftHour
                        }
                    })
                    console.log('lefthour',this.officalHour,response,this.experienceHour)
                    resolve({ officalHour: this.officalHour, experienceHour: this.experienceHour })
                })
                .catch(error => {
                    reject(error)
                })
        })
    }

    /**
     * 获取课时记录
     * type 1获取 2消耗
     * return promise
     *
     * @memberof HourStore
     */
    @action
    fetchCourseHourRecords = (type, pageNum, pageSize) => {
        let data = {userId: UserStore.id, actionType: type,pageNum: pageNum, pageSize: pageSize}
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.GetCourseHourHistory, data)
                .then(response => {
                    if (!response.data.result) {
                      response.data.result = []
                    }
                    const { result ,totalNum } = response.data

                    if (type == 0) {
                        if(!this.allHistory) {
                            this.allHistory = []
                        }
                        this.allHistory = [...this.allHistory,...result]
                    }
                    if (type == 1) {

                        if (!this.chargeHistory) {
                            this.chargeHistory = []
                        }
                        this.chargeHistory = [...this.chargeHistory, ...result]
                    }
                    else if (type == 2) {
                        if (!this.consumeHistory) {
                            this.consumeHistory = []
                        }
                        this.consumeHistory = [...this.consumeHistory, ...result]

                    }

                    let nextPage = pageNum * pageSize < totalNum ? true : false
                        resolve({ nextPage ,response : response})
                })
                .catch(error => {
                    console.log(error, type, 'console.error();', data);
                    reject(error)
                })
        })
    }

    /**
     * 向服务器验证内购购买结果
     * return promise
     *
     * @memberof OrderStore
     */
    verityIAPRecipt = (receiptData) => {
        // let postData = { user_id: UserStore.id, receipt_data: receipt_data }
        // console.log('==> 购买数据',postData)
        // return new Promise((resolve, reject) => {
        //     NetStore.fetch(CzbApi.VerifyAppleOrder, postData)
        //         .then(response => {
        //             console.log('==> 购买数据返回', response,postData)
        //             const { errorCode, errorMsg, result } = response
        //             if (errorCode == 200) {
        //                 resolve(response)
        //             }
        //             else {
        //                 reject({ errorCode, errorMsg })
        //             }
        //         })
        //         .catch(error => {
        //             console.log('==> 购买数据失败',error)
        //             reject(error)
        //         })
        // })

        let postData = {receiptData: receiptData }
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.VerifyAppleOrder,postData)
                .then(response => {
                    console.log('==> 购买数据返回', response,receiptData)
                    const { code, msg, data } = response
                    if (code == 200) {
                        resolve(response)
                    }
                    else {
                        reject({ code, msg })
                    }
                })
                .catch(error => {
                    reject(error)
                })
        })
    }

    /**
     * 本地缓存苹果内购课时数量
     *
     * @memberof User
     */
    @action
    saveIAP = (count) => {
        this.iapHour = count
        StorageStore.save('reciptApple', count)
    }

    /**
     * 读取缓存苹果内购课时数量
     *
     * @memberof User
     */
    @action
    loadIAP = () => {
        return new Promise((resolve, reject) => {
            StorageStore.load('reciptApple', () => { }, false)
                .then(response => {
                    this.iapHour = response
                    resolve(response)
                })
                .catch(error => {
                    reject(error)
                })
        })
    }

    /**
     * 添加苹果内购课时数量
     *
     * @memberof Hour
     */
    @action
    addIAP = (count) => {
        return new Promise((resolve, reject) => {
            this.loadIAP()
                .then(response => {
                    let total = count + response
                    this.saveIAP(total)
                    resolve(total)
                })
                .catch(error => {
                    this.saveIAP(count)
                })
        })
    }

    clear = () => {
        this.officalHour = 0
        this.experienceHour = 0
    }

    clearOffical = () => {
        this.officalHour = 0
    }
}

export let HourStore = new Hour
