import { observable, action, reaction, computed } from 'mobx'
import { NetStore } from '../store'
import { CzbApi } from '../model'
import {Store, UserStore,RecordsStore} from "react-native-czb"

class Interaction {

    //canvas
    @observable canvasStatus = false
    @observable canvasRender = null
    @observable canvasColor = 'black'
    @observable lineWidth = 5

    //flowers
    @observable flowerCount = 0
    @observable isShowFlowerGif = false
    @observable starAmount = 0;
    /**
     * 获取PPT列表
     *
     * return Promise
     *
     * @memberof ClassroomStore
     */
    fetchPPTList = (pptID) => {
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kFetchPPTList, null, { coursewareId: pptID, pageNum: 1, pageSize: 100})
                .then(response => {
                    const {code,data} = response;
                    console.log('fetchPPTList',response);
                    if(code == 200){
                        let pptList = data.courImgs.map(value => value.imageUrl)
                        resolve(pptList)
                    }else{
                        reject(response);
                    }
                })
                .catch(error => {
                    console.log('fetchPPTList','error',error);
                    reject(error)
                })
        })
    }

    //Videos
    videoList//开课前广告循环播放
    @observable videoIndex //开课前广告循环播放
    @observable videoUrl
    @observable videoType // 课件播放视频开启还是关闭

    /**
     * 单独播放某一个视频
     *
     * @memberof InteractionStore
     */
    @action
    playVideo = (url) => {
        this.videoUrl = url
    }

    @action
    playVideoInLoop = () => {
        this.videoIndex = 0
        this.videoUrl = this.videoList[this.videoIndex]
    }

    @action
    playNextVideoInLoop = () => {
        if (this.videoIndex >= 0) {
            if (this.videoIndex < this.videoList.length - 1) {
                this.videoIndex += 1
                this.videoUrl = this.videoList[this.videoIndex]
            }
            else {
                this.videoIndex = 0
                this.videoUrl = this.videoList[this.videoIndex]
            }
        }
    }

    @action
    closeVideoView = () => {
        this.videoIndex = null
        this.videoUrl = null
        this.videoList = null
        this.videoType = null
    }

     /**
     * 获取上课前广告视频
     *
     * @memberof ClassroomStore
     */
    fetchIntroVideo = () => {
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kFetchIntroVideo, null)
                .then(response => {
                    const { videoList } = response.data
                    this.videoList = videoList.map(value => value.videoUrl)
                    if (this.videoList && this.videoList.length > 0) {
                        this.playVideoInLoop()
                        this.videoType = 'video'
                    }
                    resolve()
                })
                .catch(error => reject(error))
        })
    }

    /**
     * 显示星星动画网页Gif
     * @param showGif 控制显示网页gif图
     * */
    @observable isShowStarGif = false
    @action
    setShowStarGif = (showGif) => {
        this.isShowStarGif = showGif;
    }

    /**
     * 获取星星数量
     * @param userId 用户id
     * @param bookedId 课程id
     * */
    @action
    fetchStarAmount = (userId,roomId)=>{
        let param = {
            userIds:[userId],
            roomId:roomId
        };
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kFetchStarAmount,param).then(response => {
                const {code,data} = response;
                console.log('fetchStarAmount',response)
                if(code == 200){
                    try{
                        this.starAmount = parseInt(data[0].currentStar)+parseInt(data[0].historyStar)
                        resolve(response);
                    }catch (e) {
                        throw e;
                    }
                }else{
                    throw response;
                }
            }).catch(error => {reject(error),console.log('fetchStarAmount','error',error)})
        })
    }

    /**
     * 星星加+1
     * */
    @action
    starAdd(){
        this.starAmount++;
    }

    //Game
    gameID
    @observable gameUrl
    @action
    startGame = (gameID, url) => {
        this.gameID = gameID
        this.gameUrl = url
    }
    @action
    closeGame = () => {
        this.gameID = null
        this.gameUrl = null
    }

    // Dynamic PPT
    @observable isCache = null
    @observable isConnect = null
    @observable ackData = null
    @observable cwmsg = null
    @observable pptUrl
    @action
    getDynamicPPT = (pptId ,roomId,classMode,roleType) => {
        this.pptUrl = CzbApi.kGetDynamicPPT + `?token=${UserStore.token}&userType=${1}&vsFrom=${Store.vsFrom}&pptID=${pptId}&senderId=${UserStore.id}&roomId=${roomId}&classMode=${classMode}&nickName=${UserStore.name}&roleType=${roleType}`
        // this.pptUrl = "http://172.18.1.16:8900/bin/index.html?" +`token=${UserStore.token}&userType=${1}&vsFrom=${Store.vsFrom}&pptID=${"5afa8d674b00f62557f73476"}&uid=${UserStore.id}`
    }

    /**
     * 重置InteractionStore
     *
     * @memberof InteractionStore
     */
    @action
    reset = () => {
        this.canvasStatus = false
        this.canvasRender = null
        this.canvasColor = 'black'
        this.lineWidth = 5
        this.flowerCount = 0
        this.isShowFlowerGif = false
        this.videoList = null
        this.videoIndex = null
        this.videoUrl = null
        this.videoList = null
        this.gameID = null
        this.gameUrl = null
        this.isConnect = null
        this.ackData = null
        this.cwmsg = null
        this.pptUrl = null
        this.isShowStarGif = false
        this.starAmount = 0
    }
}

export let InteractionStore = new Interaction
