import jsSHA from 'jssha'
import { User, CzbApi } from '../model'
import { NetStore, StorageStore, UserStore } from '../store'
import { Store } from '../Store'
import { observable, action } from 'mobx'

let JSEncryptExports = require('./jsencrypt')

class Login {

    /**
     * 是否登录
     */
    @observable isLogin = false

    /**
     * token是否失效
     *
     * @memberof LoginStore
     */
    @observable tokenInvalid = false

    /**
     * 加密公钥
     *
     * @memberof LoginStore
     */
    publicKey = null

    /**
     * 加密公钥
     *
     * return promise
     * @memberof LoginStore
     */
    fetchPublicKey = () => {
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kFetchPublicKey)
                .then(response => {
                    const { result } = response
                    this.publicKey = result
                    resolve()
                })
                .catch(error => {
                    reject(error)
                })
        })
    }
    /**
     * 账号密码登录
     * tel: 电话
     * countryCode: 国家区号
     * password: 密码
     * deviceInfo: 设备信息
     * appVersion: app信息
     *
     * return promise
     * @memberof LoginStore
     */
    accountLogin = async(tel, countryCode, password, deviceInfo, appVersion) => {
        let postData = {
              // username: tel,
              // password: this.encryptionPassword(password, this.publicKey),
              // from: Store.vsFrom,
              // type: 1,
              // country_code: countryCode,
              loginFrom: Store.vsFrom,
              mobile: tel,
              passWord: this.encryptionPassword(password),
        }
        // let query = {
        //     sys_v:deviceInfo,
        //     app_v:appVersion,
        //     isEncrypt: 1,
        // }
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kLoginURL, postData)
                .then(response => {
                  console.log(response, CzbApi.kLoginURL, postData, 'response0-0-0-');
                    // const { result } = response
                    // const { mobile: tel, userId: id, nickName: name, accessToken: token, babyStage: grade, avatar, gender } = result
                    // const isBindVideo = false
                    // // 此处需将vsFrom 置空， 因为当用户点了微信登录取消后，有直接进行账号登录，下次登录缓存的vsFrom有误的
                    // const vsFrom = null
                    // let user = new User(tel, id, name, token, grade, avatar, gender, isBindVideo, vsFrom)
                    // UserStore.userInfo = user
                    // if (!name || !grade || gender == -1) {
                    //     resolve({ needSuppleInfo: true, id: user.id })
                    // }
                    // else {
                    //     resolve({ needSuppleInfo: false, id: user.id })
                    //     this.saveLoginState(true)
                    // }

                    if (!response.data) {
                      const error = response
                      error.errorMsg = response.msg
                      return reject(error)
                    }

                    const { nopassWord, realName, token, userId, userImg } = response.data
                    const id = userId
                    const name = realName
                    // const token = token
                    const grade = null
                    const avatar = userImg
                    const gender = null
                    // // const { mobile: tel, userId: id, nickName: name, accessToken: token, babyStage: grade, avatar, gender } = result
                    // // 此处需将vsFrom 置空， 因为当用户点了微信登录取消后，有直接进行账号登录，下次登录缓存的vsFrom有误的
                    const vsFrom = null
                    let user = new User(tel, id, name, token, grade, avatar, gender, vsFrom)
                    UserStore.userInfo = user
                    NetStore.fetch(CzbApi.kGetUserInfo)
                        .then(response => {
                          const { schoolAge, gender, userImg } = response.data
                          UserStore.userInfo.grade = schoolAge
                          UserStore.userInfo.avatar = userImg
                          UserStore.userInfo.gender = gender
                          console.log(UserStore.userInfo, 'opopopo');
                          if (!UserStore.userInfo.name || !UserStore.userInfo.grade || UserStore.userInfo.gender == -1) {
                              resolve({ needSuppleInfo: true, id: user.id })
                          }
                          else {
                              resolve({ needSuppleInfo: false, id: user.id })
                              this.saveLoginState(true)
                          }
                        })
                        .catch(error => {
                          this.saveLoginState(false)
                        })
                })
                .catch(error => {
                    this.saveLoginState(false)
                    reject(error)
                })
        })
    }

    /**
     * 手机号和验证码登录
     *
     * return Promise
     * @memberof LoginStore
     */
    rapidLogin = (tel, code, countryCode, deviceInfo, appVersion, uid) => {
        // let postData = {
        //     userMobile: tel,
        //     validCode: code,
        //     countryCode: countryCode,
        //     reqFrom: Store.vsFrom,
        //     clientSysVersion: deviceInfo,
        //     clientAppVersion: appVersion,
        // }
        let postData = {
          mobile: tel,
          validCode: code,
          countryCode: countryCode,
          loginFrom: Store.vsFrom,
          reqFrom: Store.vsFrom,
          hmsr: Store.hmsr,
          hmmd: Store.hmmd,
        }
        // 有uid说明是三方绑定
        if (uid) {
          postData = {
              uid: uid,
              mobile: tel,
              validCode: code,
              countryCode: countryCode,
              loginFrom: Store.vsFrom,
              reqFrom: Store.vsFrom,
              hmsr: Store.hmsr,
              hmmd: Store.hmmd,
          }
        }
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kRapidLogin, postData)
                .then(response => {
                    console.log(response, postData, UserStore.userInfo, 'rapidLogin-=--=')
                    // const { errorCode, errorMsg, result: userInfo } = response
                    // const { mobile: tel, userId: id, nickName: name, accessToken: token, babyStage: grade, avatar, gender } = userInfo
                    // const isBindVideo = false
                    // // 此处需将vsFrom 置空， 因为当用户点了微信登录取消后，有直接进行账号登录，下次登录缓存的vsFrom有误的
                    // const vsFrom = null
                    // let user = new User(tel, id, name, token, grade, avatar, gender, isBindVideo, vsFrom)
                    // UserStore.userInfo = user
                    // if (!name || !grade || gender == -1) {
                    //     resolve({ needSuppleInfo: true })
                    // }
                    // else {
                    //     resolve({ needSuppleInfo: false })
                    //     this.saveLoginState(true)
                    // }

                    const { nopassWord, realName, token, userId, userImg } = response.data
                    const id = userId
                    const name = realName
                    // const token = token
                    const grade = null
                    const avatar = userImg
                    const gender = null
                    // // const { mobile: tel, userId: id, nickName: name, accessToken: token, babyStage: grade, avatar, gender } = result
                    // // 此处需将vsFrom 置空， 因为当用户点了微信登录取消后，有直接进行账号登录，下次登录缓存的vsFrom有误的
                    const vsFrom = null
                    let user = new User(tel, id, name, token, grade, avatar, gender, vsFrom)
                    UserStore.userInfo = user
                    console.log(UserStore.userInfo, 'opopopo');
                    NetStore.fetch(CzbApi.kGetUserInfo)
                        .then(response => {
                          const { schoolAge, gender, userImg } = response.data
                          UserStore.userInfo.grade = schoolAge
                          UserStore.userInfo.avatar = userImg
                          UserStore.userInfo.gender = gender
                          if (!UserStore.userInfo.name || !UserStore.userInfo.grade || UserStore.userInfo.gender == -1) {
                              resolve({ needSuppleInfo: true, id: user.id })
                          }
                          else {
                              resolve({ needSuppleInfo: false, id: user.id })
                              this.saveLoginState(true)
                          }
                        })
                        .catch(error => {
                          this.saveLoginState(false)
                        })
                })
                .catch(error => {
                    this.saveLoginState(false)
                    reject(error)
                })
        })
    }

    /**
     * 三方登录是否已绑定用户
     *
     * return Promise
     * @memberof LoginStore
     */
     isThirdUserHasBind = (uid, reqFrom) => {

         let postData = {
             uid: uid,
             reqFrom: reqFrom,
             loginFrom: Store.vsFrom,
         }
         // console.log(postData, '9009090');
         return new Promise((resolve, reject) => {
             NetStore.fetch(CzbApi.kRapidLogin, postData)
                 .then(response => {
                     console.log(response, postData, 'thirdUserRegist');
                     // 三方登录修改请求头中vsFrom
                     // Store.vsFrom = postData.from
                     // const { errorCode, errorMsg, result: userInfo } = response
                     // const {
                     //   mobile: tel,
                     //   userId: id,
                     //   nickName: name,
                     //   accessToken: token,
                     //   babyStage: grade,
                     //   avatar,
                     //   gender
                     // } = userInfo
                     // const vsFrom = Store.vsFrom
                     // let user = new User(tel, id, name, token, grade, avatar, gender, vsFrom)
                     // UserStore.userInfo = user
                     // if (!name || !grade || gender == -1) {
                     //     resolve({ needSuppleInfo: true })
                     // }
                     // else {
                     //     resolve({ needSuppleInfo: false })
                     //     this.saveLoginState(true)
                     // }
                     Store.vsFrom = postData.reqFrom
                     // console.log(Store.vsFrom, 'Store.vsFrom-=-=-=');
                     const { nopassWord, realName, token, userId, userImg, userType } = response.data
                     // userType == -1 用户未绑定三方账号
                     if (userType == -1) {
                       this.saveLoginState(false)
                       return reject(response.data)
                     }
                     const id = userId
                     const name = realName
                     // const token = token
                     const grade = null
                     const avatar = userImg
                     const gender = null
                     const vsFrom = Store.vsFrom
                     const tel = null
                     let user = new User(tel, id, name, token, grade, avatar, gender, vsFrom)
                     UserStore.userInfo = user
                     NetStore.fetch(CzbApi.kGetUserInfo)
                         .then(response => {
                           const { schoolAge, gender, userImg, mobile } = response.data
                           UserStore.userInfo.tel = mobile
                           UserStore.userInfo.grade = schoolAge
                           UserStore.userInfo.avatar = userImg
                           UserStore.userInfo.gender = gender
                           console.log(UserStore.userInfo, 'kGetUserInfo');

                           if (!UserStore.userInfo.name || !UserStore.userInfo.grade || UserStore.userInfo.gender == -1) {
                               resolve({ needSuppleInfo: true, id: user.id })
                           }
                           else {
                               resolve({ needSuppleInfo: false, id: user.id })
                               this.saveLoginState(true)
                           }
                         })
                         .catch(error => {
                           this.saveLoginState(false)
                         })
                 })
                 .catch(error => {
                     console.log(error, 'thirdUserRegist error');
                     this.saveLoginState(false)
                     reject(error)
                 })
         })
     }
    /**
     * 第三方登录绑定
     * 新逻辑为先修改资料再登录
     * return Promise
     * @memberof LoginStore
     */


    /**
     * 获取短信验证码
     *
     * return promise
     * @memberof LoginStore
     */
    fetchVerifyCode = (tel, countryCode) => {
        var data = { mobile: tel, country_code: countryCode }
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kFetchCodeURL, data)
                .then(response => {
                    resolve()
                })
                .catch(error => {
                    reject(error)
                })
        })
    }

    /**
     * 验证验证码
     *
     * return promise
     * @memberof LoginStore
     */
    verifyCode = (tel, code, countryCode) => {
        let data = {
            // country_code: countryCode,
            // verify_code: code,
            // mobile: tel,
            mobile: tel,
            countryCode: countryCode,
            validCode: code,
        }
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kVerifyCodeURL, data)
                .then(response => {
                  // 需要返回获取到的uuid,用于重置密码
                    // console.log(response, data, 'verifyCode-==-');
                    resolve(response)
                })
                .catch(error => {
                    console.log(error, 'verifyCode-==-error');
                    reject(error)
                })
        })
    }

    /**
     * 重置密码
     */
    revisePassword = (tel, code, countryCode, newPSD) => {
        let data = {
            // country_code: countryCode,
            // verify_code: code,
            // mobile: tel,
            // passWord: newPSD
            mobile: tel,
            newPassWordOne: this.encryptionPassword(newPSD),
            newPassWordTwo: this.encryptionPassword(newPSD),
            uuid: code,
        }
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kModifyPasswordURL, data)
                .then(response => {
                    console.log('revisePassword', response, data, CzbApi.kModifyPasswordURL);
                    resolve(response)
                })
                .catch(error => {
                    reject(error)
                })
        })
    }

    /**
     * 手机号密码注册(Deprecated)
     *
     * return promise
     * @memberof LoginStore
     */
    regist = async(tel, password, code, countryCode, grade, name) => {
        if (!this.publicKey) {
          await this.fetchPublicKey()
        }
        let postData = {
            mobile: this.tel,
            passWord: this.encryptionPassword(password, this.publicKey),
            verify_code: this.code,
            register_from: Store.vsFrom,
            country_code: this.countryCode,
            babyStage: gradeParams,
            nickName: name,
        }
        let url = CzbApi.kRegistURL + '?isEncrypt=1'
        return new Promise((resolve, reject) => {
            NetStore.fetch(url, postData)
                .then(response => {
                    const { result } = response
                    const { userId: id, name, accessToken: token, gradeParams: grade, avatar, gender } = result
                    const isBindVideo = false
                    // 此处需将vsFrom 置空， 因为当用户点了微信登录取消后，有直接进行账号登录，下次登录缓存的vsFrom有误的
                    const vsFrom = null
                    let user = new User(tel, id, name, token, grade, avatar, gender, isBindVideo, vsFrom)
                    UserStore.userInfo = user
                    resolve()
                })
                .catch(error => {
                    reject(error)
                })
        })
    }

    /**
     * 退出登录
     *
     * @memberof LoginStore
     */
     loginOut = () => {
       return new Promise((resolve, reject) => {
           NetStore.fetch(CzbApi.kLoginOut, {})
               .then(response => {
                   // console.log(response, 'loginOut-=-=-');
                   resolve()
               })
               .catch(error => {
                   reject(error)
               })
       })
     }

    /**
     * 保存登录状态，缓存沙盒
     *
     * @memberof LoginStore
     */
    @action
    saveLoginState = (isLogin) => {
        this.isLogin = isLogin
        if (!isLogin) {
            UserStore.userInfo = null
        }
        console.log(isLogin, 'isLogin');
        StorageStore.save('isLogin', isLogin)
    }

    /**
     * 从沙盒读取登录状态
     *
     * return promise
     * @memberof LoginStore
     */
    loadLoginState = () => {
        return new Promise((resolve, reject) => {
            StorageStore.load('isLogin', () => { }, false)
                .then(response => {
                    this.isLogin = response
                    resolve(response)
                })
                .catch(error => {
                    this.isLogin = false
                    reject(error)
                })
        })

    }

    /**
     * RSA密码加密
     *
     * @memberof LoginStore
     */
    encryptionPassword = (ps, count = 3) => {
        // if (!password) return console.log('no password')
        // if (!pubkey) return console.log('no public key')
        // var JSEncrypt = JSEncryptExports.JSEncrypt
        // var encrypt = new JSEncrypt()
        // encrypt.setPublicKey(pubkey)
        // return encrypt.encrypt(password)
        if (!ps) return false;
        let i = (password) => {
            let shaObj = new jsSHA('SHA-512', 'TEXT')
            shaObj.update(password)
            shaObj.getHash('HEX').substr(1, 32)
            return shaObj.getHash('HEX').substr(1, 32);
        }

        ps = i(i(ps)) + i(ps);

        while(count > 0) {
            ps = i(ps);
            count--
        }
        return ps;
    }

    verifyTel = (tel) => {
        return (/^1[0-9]{10}$/.test(tel))
    }

    verifyPassword = (password) => {
        return /^[a-zA-Z0-9]{6,16}$/.test(password)
    }

}

export let LoginStore = new Login
