import { NetStore, UserStore } from '../store'
import { CzbApi } from '../model'
import { observable, action, computed } from 'mobx'
import moment from 'moment'

class Message {

    @observable originalMessage = []
    @observable formattedMessage = []
    @computed get showDot() {
        return this.message.length > 0
    }

    /**
     * 获取预约消息记录
     *
     * @memberof MessageStore
     */
    @action
    fetchReservationMessage = (pageNum = 1, pageSize = 10) => {
        let getData = {
            userId: UserStore.id,
            pageNum: pageNum,
            pageSize: pageSize
        }
        let url = CzbApi.GetReservationMessage
        return new Promise((resolve, reject) => {
            NetStore.fetch(url, getData)
                .then(response => {
                    const { total, pushMsgs } = response.data

                        this.originalMessage = pushMsgs
                        this.formatMessage(pushMsgs)
                        let nextPage = pageNum * pageSize < total ? true : false
                        resolve({ nextPage })
                })
                .catch(error => {
                    reject(error)
                })
        })
    }

    // /**
    //  * 解析从服务器获取的通知消息
    //  * return object
    //  * @memberof MessageStore
    //  */
    // @action
    // parseMessage = (message) => {
    //     if (!this.message) {
    //         this.message = []
    //     }
    //     const dataArray = []
    //     for (let i = 0; i < message.length; i++) {
    //         let dateString = message[i].createDate.slice(0, 10)//日期
    //         let timeString = message[i].createDate.slice(11, 16)//时间
    //         let hourString = parseInt(message[i].createDate.slice(11, 13)) < 13 ? '上午' : '下午'
    //         let now = moment().format('YYYY-MM-DD')
    //         let show = dateString + " " + hourString + timeString
    //         dataArray.push({
    //             key: message[i].id,
    //             time: show,
    //             title: message[i].msg_title,
    //             content: message[i].msg_body,
    //         })
    //     }
    //     this.message = [...this.message, ...dataArray]
    // }

    formatMessage = (message) => {
        let formattedMessage = message.map(value => {
            let show = value.createDate
            let dateString = value.createDate.slice(0, 10)
            let timeString = value.createDate.slice(11)
            let now = moment().format('YYYY-MM-DD')
            //今天
            if (moment(now).isSame(dateString)) {
                show = '今天 ' + timeString
            }
            //昨天
            if (moment(now).isSame(dateString, 'year') && moment(now).isSame(dateString, 'month') && moment().get('date') - moment(dateString).get('date') == 1) {
                show = '昨天 ' + timeString
            }
            return {
                time: show,
                title: value.msgTitle,
                content: value.msgBody,
            }
        })
        if (!this.formattedMessage) {
            this.formattedMessage = []
        }
        this.formattedMessage = [...this.formattedMessage, ...formattedMessage]
    }

    @action
    clearMessage() {
        this.originalMessage = []
        this.formattedMessage = []
    }
}

export let MessageStore = new Message()
