/**
 * @desc 用于网络连接情况的监听
 * */
import { observable, action } from 'mobx'
import {NetInfo} from 'react-native'
class NetInfoState {
    @observable isConnected = true
    @observable isWifi = false

    /**
     * @desc 添加网络状态监听器
     * */
    addNetInfoListener = ()=>{
        NetInfo.isConnected.addEventListener('change',this._dealChange);
        NetInfo.addEventListener('connectionChange',this.handleNetInfo);
    }

    @action
    _dealChange = (isConnected)=>{
        this.isConnected = isConnected;
    }

    @action
    handleNetInfo = (type, effectiveType) => {
        if (this.isConnected) {
            if (type.type == 'wifi') {
                this.isWifi = true;
            } else {
                this.isWifi = false
            }
        }
    }

    /**
     * @desc 移除网络状态监听器
     * */
    removeNetInfoListener = ()=>{
        NetInfo.isConnected.removeEventListener('change',this._dealChange)
        NetInfo.removeEventListener('connectionChange',this.handleNetInfo)
    }
}
export let NetInfoStore = new NetInfoState()