import { Store } from '../Store'
import { CzbError } from '../model'
import { UserStore, LoginStore ,StorageStore} from '../store'
import { DeviceEventEmitter } from 'react-native'
import RNFetchBlob from '../../../react-native-fetch-blob/index'
import {CzbApi} from "react-native-czb/src/model/index";
import _ from 'lodash'
export const NetStore = {

    timeOut : 8000,
    uploadTimeout:10000,
    /**
     * @desc rn fetch方法不带超时功能,为了少做判断提高性能换fetchblob.
     * @param url 请求网址
     * @param data post请求传data
     * @param query get请求
     * @return promise
     */
    fetch: (url, data, query)=>{
        let token = UserStore.userInfo ? UserStore.token : null
        let headers = {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
        }
        headers['login-from'] = Store.vsFrom
        headers.version = Store.appVersion
        if (token) {
            headers.token = token
        }
        let method = data ? 'POST' : 'GET';
        let body = data ? data: null;//post传的是数据 get是拼的Url 其实可以不用拼的
        if (query) {
            let url_params = `${url}?`
            for (let key in query) {
                url_params = `${url_params}${key}=${query[key]}&`
            }
            url = url_params.substring(0, url_params.length - 1)
            console.log(url)
        }
        return new Promise((resolve,reject)=>{
            RNFetchBlob.config({
                timeout:NetStore.timeOut
            }).fetch(method,url,headers,JSON.stringify(body)).then(
                (response)=>{
                    const {status} = response.respInfo;//状态码
                    const {data:responseText} = response;//数据
                    if(status == 200){//接口请求成功
                        if (responseText != '' && responseText != null) {
                            //Json
                            if (NetStore.isJson(responseText)) {
                                //验证token有效性
                                let responseJSON = JSON.parse(responseText)
                                let code = Number(responseJSON.code)
                                let errorMsg = responseJSON.msg
                                // token失效错误码 10002  10008
                                // if (code === 404 || code === 403 || code === 402 || code === 401) {
                                if (code === 10002 || code === 10008) {
                                    LoginStore.tokenInvalid = true
                                    LoginStore.saveLoginState(false)
                                    reject({ errorCode: 9002, errorMsg: CzbError[9002] })
                                }
                                else if (!isNaN(code) && code != 200) {
                                    reject({ errorCode: code, errorMsg: errorMsg })
                                }
                                else {
                                    resolve(responseJSON)
                                }
                            }
                            else {
                                resolve(responseText)
                            }
                        }
                        else {
                            resolve(responseText)
                        }
                    }else {
                        return reject({ errorCode: response.status, errorMsg: `Http Request Error ${response.status}` })
                    }
                }
            ).catch((error)=>{
                reject({ errorCode: 9000, errorMsg: CzbError[9000] })
            })
        })
    },

    /**
     * @desc 请求数据(支持带有缓存请求数据一次请求)
     * @param url 请求网址
     * @param data post请求传data
     * @param query get请求
     * @param isCache 要不要缓存 为true的话走缓存请求 为false继续走原来fetch请求功能
     * @param cacheCallback 缓存数据回调
     * */
    fetchWithCache:(url, data, query,isCache = true,cacheCallback)=>{
        let param = data||query;
        let key;
        if(param == undefined || param == null){
            key = url
        }else{
            key = url+JSON.stringify(param);
        }
        if(isCache){
            let result = StorageStore.readSyncData(key);
            if(result.length >0){//表示有读取到数据
                cacheCallback&&cacheCallback(JSON.parse(result));//把缓存数据回调出去
                return new Promise((resolve,reject)=>{
                    NetStore.fetch(url,data,query).then((response)=>{
                        let a = Object.assign({},JSON.parse(result));
                        let b = Object.assign({},response);
                        if(_.isEqual(a,b)||JSON.stringify(a) == JSON.stringify(b)){
                            resolve({//console.log("数据相同");
                                code: 200,
                                msg: "数据相同",
                                data: response.data,
                                isSameData:true
                            });
                        }else{
                            StorageStore.saveSyncData(key,response);//console.log("数据不相同",a,b,"key",key,"data:",data,"query",query);
                            resolve(response);
                        }
                    }).catch(error=>{
                        reject(error);
                        console.log(error)
                    })
                })
            }else{//没有读取到数据
                return new Promise((resolve,reject)=>{//console.log("没有保存数据走一般请求");
                    NetStore.fetch(url,data,query).then((response)=>{
                        StorageStore.saveSyncData(key,response);
                        resolve(response);
                    }).catch(error=>{
                        reject(error);
                    })
                })
            }
        }else{//不开启缓存走一般请求
            return new Promise((resolve,reject)=>{
                NetStore.fetch(url,data,query).then((response)=>{
                    resolve(response);
                }).catch(error=>{
                    reject(error);
                })
            })
        }
    },


    //上传图片
    uploadPicture: (url, uid, picUri, type) => {

        let formData = new FormData()
        let file = { uri: picUri, type: 'multipart/form-data', name: 'text.jpg' }
        formData.append('avatar', file)
        formData.append('uid', uid)
        // formData.append('type', type)
        var abort_fn = null
        //这是一个可以被reject的promise
        var abort_promise = new Promise(function (resolve, reject) {
            abort_fn = function () {
                reject({ errorCode: 9001, errorMsg: CzbError[9001] })
            }
        })
        let token = UserStore.userInfo ? UserStore.token : null
        let headers = {
            'Accept': 'application/json',
            'Content-Type': 'multipart/form-data',
        }
        headers['login-from'] = Store.vsFrom
        headers.version = Store.appVersion
        if (token) {
            headers.token = token
            // headers.userType = 1
        }
        var fetch_promise = new Promise((resolve, reject) => {
            fetch(url, {
                method: 'post',
                headers: headers,
                body: formData,
            })
                .then(response => response.text())
                .then(responseText => resolve(JSON.parse(responseText)))
                .catch(error => reject({ errorCode: 9000, errorMsg: CzbError[9000] }))
        })

        //这里使用Promise.race，以最快 resolve 或 reject 的结果来传入后续绑定的回调
        var abortable_promise = Promise.race([
            fetch_promise,
            abort_promise
        ])
        setTimeout(function () {
            abort_fn()
        }, 10000)
        return abortable_promise
    },

    isJson: (value) => {
        if (typeof value == 'string') {
            try {
                let object = JSON.parse(value)
                return true
            }
            catch (error) {
                return false
            }
        }
        return false
    }
    // /**
    //  * @desc 上传图片
    //  * */
    // uploadPicture: (url, uid, picUri, type) => {
    //     let token = UserStore.userInfo ? UserStore.token : null
    //     let headers = {
    //         'Accept': 'application/json',
    //         'Content-Type' : 'application/octet-stream',
    //     }
    //     headers['login-from'] = Store.vsFrom
    //     headers.version = Store.appVersion
    //     if (token) {
    //         headers.token = token
    //     }
    //     //console.log('uploadPicture',RNFetchBlob.wrap(picUri));
    //     return new Promise((resolve,reject)=>{
    //         RNFetchBlob.config({
    //             timeout:this.uploadTimeout
    //         }).fetch('POST',url,headers,
    //             [
    //              {name:'avatar',data: RNFetchBlob.wrap(picUri)}
    //             ]).then(response =>{
    //                 console.log("uploadPicture",response)
    //                 const {status} = response.respInfo;//状态码
    //                 const {data:responseText} = response;//数据
    //                 if(status == 200){
    //                     resolve(responseText);
    //                 }else{
    //                     throw response
    //                 }
    //             }).catch(error=>{
    //             console.log("uploadPicture",error)
    //                 reject({ errorCode: 9000, errorMsg: CzbError[9000] })
    //             })
    //     })
    // },
    // /*
    // * url: 接口地址
    // * data: post data
    // * query: 查询参数
    // * return Promise
    // */
    // fetch: (url, data, query) => {
    //     var abort_fn = null
    //     //这是一个可以被reject的promise
    //     var abort_promise = new Promise(function (resolve, reject) {
    //         abort_fn = function () {
    //             reject({ errorCode: 9001, errorMsg: CzbError[9001] })
    //         }
    //     })
    //     let token = UserStore.userInfo ? UserStore.token : null
    //     let headers = {
    //         'Accept': 'application/json',
    //         'Content-Type': 'application/json',
    //     }
    //     headers['login-from'] = Store.vsFrom
    //     headers.version = Store.appVersion
    //     if (token) {
    //         headers.token = token
    //         // headers.userType = 1
    //     }
    //     if (query) {
    //         let url_params = `${url}?`
    //         for (let key in query) {
    //             url_params = `${url_params}${key}=${query[key]}&`
    //         }
    //         url = url_params.substring(0, url_params.length - 1)
    // 	console.log(url)
    //     }
    //     let options = {
    //         method: data ? 'post' : 'get',
    //         headers,
    //     }
    //     if (data) {
    //         options.body = JSON.stringify(data)
    //     }
    //     var fetch_promise = new Promise((resolve, reject) => {
    //         fetch(url, options)
    //             .then(response => {
    //                 if (response.status == 200) {
    //                     return response.text()
    //                 }
    //                 else {
    //                     return reject({ errorCode: response.status, errorMsg: `Http Request Error ${response.status}` })
    //                 }
    //             })
    //             .then(responseText => {
    //                 if (responseText != '' && responseText != null) {
    //                     //Json
    //                     if (NetStore.isJson(responseText)) {
    //                         //验证token有效性
    //                         let responseJSON = JSON.parse(responseText)
    //                         let code = Number(responseJSON.errorCode)
    //                         let errorMsg = responseJSON.errorMsg
    //                         if (code === 404 || code === 403 || code === 402 || code === 401) {
    //                             LoginStore.tokenInvalid = true
    //                             LoginStore.saveLoginState(false)
    //                             reject({ errorCode: 9002, errorMsg: CzbError[9002] })
    //                         }
    //                         else if (!isNaN(code) && code != 200) {
    //                             reject({ errorCode: code, errorMsg: errorMsg })
    //                         }
    //                         else {
    //                             resolve(responseJSON)
    //                         }
    //                     }
    //                     else {
    //                         resolve(responseText)
    //                     }
    //                 }
    //                 else {
    //                     resolve(responseText)
    //                 }
    //             })
    //             .catch(error => {
    //                 reject({ errorCode: 9000, errorMsg: CzbError[9000] })
    //             })
    //     })
    //
    //     //这里使用Promise.race，以最快 resolve 或 reject 的结果来传入后续绑定的回调
    //     var abortable_promise = Promise.race([
    //         fetch_promise,
    //         abort_promise
    //     ])
    //     setTimeout(function () {
    //         abort_fn()
    //     }, 8000)
    //
    //     // catch the timeout error, emit the event that for handle the error.
    //     // The listener is in the inherice class
    //     var catchTimeoutPromise = new Promise((resolve, reject) => {
    //       abortable_promise
    //         .then((response) => {
    //           resolve(response)
    //         })
    //         .catch((error) => {
    //           if (error.errorCode === 9001) {
    //             DeviceEventEmitter.emit(CzbError[9001])
    //           }
    //           reject(error)
    //         })
    //     })
    //     return catchTimeoutPromise
    // },


}
