import { Store } from '../Store'
import { NetStore, StorageStore, ReservationStore, UserStore } from '../store'
import { CzbApi } from '../model'
import { action, observable, computed } from 'mobx'

class Order {

    @observable unPaidData = []
    @observable paidData = []

    @computed get showDot() {
        return this.unPaidData.length > 0
    }

    /**
     * 获取订单数据
     * return Promise
     * NONPAYMENT(0, "未支付"),
       PAYED(1, "已支付"),
       CLOSED(2, "已关闭");
     * @memberof OrderStore
     */
    @action
    fetchOrderList = () => {
        let postData = {userId: UserStore.id }
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kOrderList, null, postData)
                .then(response => {
                    console.log('order',response)
                    this.unPaidData.splice(0)
                    this.paidData.splice(0)
                    const { data } = response
                    data.map((value, index) => {
                        const { orderStatus: orderStatus } = value
                        if (orderStatus == 0) {
                            this.unPaidData.push(value)
                        }
                        else if (orderStatus == 1) {
                            this.paidData.push(value)
                        }
                    })
                    resolve()
                })
                .catch(error => {
                    reject(error)
                })
        })
    }


    /**
     * 提交订单
     * return Promise
     *
     * @memberof OrderStore
     * orderId goodsId goodsNum userId reqFrom payType orderType
     */
    commitOrder = (orderId, payType, platform, hbfqNum,userMobile , userName ,userEmail , period) => {
        let postData = {
            orderId: orderId,
            reqFrom: platform,
            payType: payType,
        }
        if (hbfqNum) {
            postData.stage = hbfqNum
        }
        if (payType === 'umoney') {
            postData.userName = userName,
            postData.userMobile = userMobile,
            postData.userEmail = userEmail,
            postData.stage = period
        }
        console.log('orderpostdata',postData)
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kCommitOrder,postData)
                .then(response => {
                    console.log('orderresponse',response)
                    const { code, msg, data } = response
                    if (code == 200) {
                        resolve(data.charge)
                    }
                    else {
                        reject({errorCode: code, errorMsg: response.msg})
                    }
                })
                .catch(error => {
                    reject(error)
                })
        })
    }

    @observable cmbCharge = null

    commitCMBOrder = (orderId, goodsId, goodsNum, payType, platform) => {
        let postData = {
            orderId: orderId,
            goodsId: goodsId,
            goodsNum: goodsNum,
            userId: UserStore.id,
            reqFrom: platform,
            payType: payType,
            orderType: 1,
        }
        console.log(postData)
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kOrderByCMB, postData)
                .then(response => {
                    console.log('res', response)
                    const {errorInfo, orderNo, pingppCharge, validateTag} = response
                    if (validateTag) {
                        resolve(pingppCharge)
                    }
                })
                .catch(error => {
                    reject(error)
                })
        })

    }

    clear = () => {
        this.unPaidData.splice(0)
        this.paidData.splice(0)
    }
}

export let OrderStore = new Order