/*
常见问题Qa相关接口
*/

import { observable, action, computed, reaction } from 'mobx'
import { NetStore } from '../store'
import { CzbApi } from '../model'
import { Store } from '../Store'

class QaInfo {
  // 问题分类列表数据
  @observable qaQuestionClass = []
  @observable currrentTabIndex = 0
  @observable initTabDatas = []

  @observable questionDetailInfo = null
  @observable questionDetailError = false
  @computed get tabNames() {
    const tabNames = this.qaQuestionClass.map((item) => {
      return item.name
    })
    return tabNames
  }
  getInitTabDatas = (data) => {
    const tabData = []
    data.forEach((item) => {
      const newItem = {...item}
      // isLoadingMore: false,//是否正在加载更多
      // isRefresh: false,//是否在刷新
      // error: false,
      // data: [],//数据
      // returnCount: 0,
      newItem.isLoading = false
      newItem.isRefresh = false
      newItem.error = false
      newItem.data = []
      newItem.returnCount = 0
      newItem.pageNum = 1
      tabData.push(newItem)
    })
    this.initTabDatas = tabData
  }



  // 获取问题分类列表
  @action
  fetchQaQuestionClass = () => {
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kFetchQaQuestionClass, null)
        .then(response => {
          console.log(response, 'fetchQaQuestionClass');
          const data = response.data
          this.qaQuestionClass = data
          this.getInitTabDatas(data)
          resolve()
        })
        .catch(error => {
          reject(error)
        })
    })
  }
  // 获取问题某一分类下无限列表
  @action
  fetchAllQuestionsByTypeId = (queryData) => {
    const query = {
      typeId: queryData.typeId,
      pageSize: queryData.pageSize,
      pageNum: queryData.pageNum,
    }
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kFetchAllQuestionsByTypeId, query)
        .then(response => {
          console.log(response, query, 'fetchAllQuestionsByTypeId-=-=-=-=-');
          const data = response.data && response.data.questionList
          resolve(data)
        })
        .catch(error => {
          // console.log(CzbApi.kFetchAllQuestionsByTypeId, error, query, 'error-=-=-=-=-');
          reject(error)
        })
    })
  }
  // 查看问题详情
  @action
  fetchQuestionsById = (id) => {
    const query = {
      id: id,
    }
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kFetchQuestionDetailById, null, query)
        .then(response => {
          console.log(query, response, 'fetchQuestionsById-=-=-=-=-');
          this.questionDetailError = false
          const data = response.data.content
          this.questionDetailInfo = data
          resolve(response.data.content)
        })
        .catch(error => {
          this.questionDetailError = true
          reject(error)
        })
    })
  }

}

export const QAStore = new QaInfo
