import { observable, action, computed, runInAction } from 'mobx'
import { CzbApi, CzbCourseType } from '../model'
import { NetStore } from '../store'
import moment from 'moment'

export class RecordsModel {
    /**
     * 生成课程model
     *
     * @param {房间id} classroomID
     * @param {课程id} courseID
     * @param {房间号 自己系统记录的} roomNum
     * @param {sdk类型} sdkType //第三方厂商类型：CC、SW(声网)、DBY(多贝云)、TKY(拓客云)
     * @param {第三方房间号 第三方系统记录的} otherThirdRoomNum
     * @param {房间密码} classroomPassword
     * @param {课程类型} courseType //1:1V1正式课 2：1V1体验课 3：1V多正式课 4：1V多体验课
     * @param {上课时间} timestamp
     * @param {教师id 系统记录} teacherID
     * @param {教师userid} teacherUserId
     * @param {教师姓名} teacherName
     * @param {静态课件id} pptID
     * @param {动态课件id} dynamicId
     * @param {课件名称} coursewareName
     * @param {课程时长} courseLong
     * @param {教室状态} courseStatus // 0未开始，1进行中,2已完成,3已删除,4开启失败
     * @param {课件类型} pptType // STATIC(静态)，DYNAMIC(动态)
     * @param {课后报告状态} reportStatus //  0 未读 1 已读 2未上传
     * @param {课后作业状态} homeWorkStatus // 0 已上传未完成 1 已完成 2 未上传
     * @param {今日课程30分钟判断} todayCourseTimeType // 0 超过30分钟 1 小于30分钟
     * @param {是否开课5分钟} todayCourseMin // 0 五分钟之内， 1 五分钟之外
     * @param {是否开始上课} timeClassStart // 0 未开始上课 1 已经开始上课
     * @param {是否结束上课} isFinishedClass // 0 未结束上课 1 结束上课
     * @param {课程结束时间两分钟前} courseEndTime // 课程真正结束时刻前2分钟即可认为课程结束
     * @param {课程正常结束时间}  courseEndAtTime //课程真正结束时间，用在首页刷新调用
     * @param {清除缓存时间} isCacheTime
     */

    constructor(
        classroomID,
        courseID,
        roomNum,
        sdkType,
        otherThirdRoomNum,
        classroomPassword,
        courseType,
        timestamp,
        teacherID,
        teacherUserId,
        teacherName,
        pptID,
        dynamicId,
        coursewareName,
        courseLong,
        courseStatus,
        pptType,
        reportStatus,
        homeWorkStatus,
        todayCourseTimeType,
        todayCourseMin,
        timeClassStart,
        isFinishedClass,
        courseEndTime,
        courseEndAtTime,
        isCacheTime,
    ) {
        this.classroomID = classroomID
        this.courseID = courseID
        this.roomNum = roomNum
        this.sdkType = sdkType
        this.otherThirdRoomNum = otherThirdRoomNum
        this.classroomPassword = classroomPassword
        this.courseType = courseType
        this.timestamp = timestamp
        this.teacherID = teacherID
        this.teacherUserId = teacherUserId
        this.teacherName = teacherName
        this.pptID = pptID
        this.dynamicId = dynamicId
        this.coursewareName = coursewareName
        this.courseLong = courseLong
        this.courseStatus = courseStatus
        this.pptType = pptType
        this.reportStatus = reportStatus
        this.homeWorkStatus = homeWorkStatus
        this.todayCourseTimeType = todayCourseTimeType
        this.todayCourseMin = todayCourseMin
        this.timeClassStart = timeClassStart
        this.isFinishedClass = isFinishedClass
        this.courseEndTime = courseEndTime
        this.courseEndAtTime = courseEndAtTime
        this.isCacheTime = isCacheTime
    }

    getCourseTypeString = () => {
        if (this.courseType == CzbCourseType.oto) {
            return '一对一'
        } else if (this.courseType == CzbCourseType.otoExp) {
            return '一对一'
        } else if (this.courseType == CzbCourseType.otm) {
            return '小班课'
        } else if (this.courseType == CzbCourseType.otmExp) {
            return '小班课'
        } else if (this.courseType == CzbCourseType.otmAuditor) {
            return '旁听'
        }
    }
}





class Records {

    @observable allCourse = [] //所有课程
    @observable todayCourse //今日课程
    @observable unfinishedCourse = []
    @observable finishedCourse = []
    @observable todayUnfinishedCourse = [] // 今日未完成课程(除了今日第一节)
    @observable todayAllUnfinishedCourse = [] // 今日所有未完成课程
    @observable tagResult = null; //默认为空

    // 转换时间戳为日期
    fetchTimeStamp = (timestamp, split) => {
        var date = new Date(timestamp * 1000); //时间戳为10位需*1000，时间戳为13位的话不需乘1000
        Y = date.getFullYear() + split; //'-'
        M = (date.getMonth() + 1 < 10 ? '0' + (date.getMonth() + 1) : date.getMonth() + 1) + split;
        D = date.getDate() + ' ';
        h = date.getHours() + ':';
        m = date.getMinutes() + ':';
        s = date.getSeconds();
        return Y + M + D + h + m + s;
    }

    // 获取课程列表新接口
    @action
    fetchCourseRecords = (pageNum, pageSize, serverTimeNow) => {
        console.log('每次传什么',pageNum,pageSize)
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kFetchCourseRecords, null, {
                pageNum,
                pageSize
            })
                .then(response => {
                    console.log('看看这个是什么什么什么',response)
                    let {result, totalNum} = response.data
                    let classStatus_1 = result.filter((item) => {
                        return item.status === 0 || item.status === 1
                    })
                    classStatus_1 = classStatus_1.reverse()
                    const classStatus_0 = result.filter((item) => {
                        return item.status === 2
                    })
                    result = [...classStatus_1, ...classStatus_0]
                    //  此处classStatus 1 应该排序颠倒 后台返回数据是默认倒叙， 此处针对该类型应升序
                    if (pageNum == 1) {
                        this.todayCourse = null
                        this.unfinishedCourse = []
                        this.finishedCourse = []
                        this.todayUnfinishedCourse = []
                        this.todayAllUnfinishedCourse = []
                    }
                    let _allCourse = []
                    let _finishedCourse = []
                    let _unfinishedCourse = []
                    let _todayUnfinishedCourse = []
                    let _todayAllUnfinishedCourse = []
                    result.map((value, index) => {

                        const {
                            roomId: classroomID,
                            arrangingId: courseID,
                            roomNum:roomNum,
                            otherThirdType: sdkType,
                            otherThirdRoomNum:otherThirdRoomNum,
                            talkerPass: classroomPassword,
                            classType: courseType,
                            bookTime: timestamp,
                            teacherId:teacherID,
                            teacherUserId:teacherUserId,
                            teacherName:teacherName,
                            coursewareId: pptID,
                            dynamicId:dynamicId,
                            coursewareName:coursewareName,
                            whenLong: courseLong,
                            status: courseStatus,
                            coursewareType: pptType, // 课件类型 1 静态 2 动态
                            reportStatus:reportStatus,
                            homeWorkStatus:homeWorkStatus,
                        } = value

                        let courseEndTime = (parseInt(value.whenLong) - 2) * 60 * 1000 + value.bookTime //课程真正结束时刻前2分钟即可认为课程结束
                        let courseEndAtTime = (parseInt(value.whenLong)) * 60 * 1000 + value.bookTime // 课程真正结束时间，用在首页刷新调用
                        let isCacheTime = value.bookTime + 3 * 60 * 60 * 1000 // 动态课件清理缓存时间 上课三小时之后清除

                        const day = moment(value.bookTime).format('YYYY-MM-DD')
                        const today = moment().format('YYYY-MM-DD')
                        let todayCourseTimeType = 0 // 是否为30分钟之内可进课程
                        let todayCourseMin = 0 // 判断是否是开课5分钟之内
                        let timeClassStart = 0 // 未开始上课
                        let isFinishedClass = 0 // 未结束上课
                        let classTimeDate = new Date(this.fetchTimeStamp(value.bookTime / 1000 + '', '-'))
                        let classTimeDateOne = new Date(this.fetchTimeStamp(value.bookTime / 1000 + '', '/'))
                        classTimeDate = Date.parse(classTimeDate) || Date.parse(classTimeDateOne)
                        let serverTimeDate = new Date(this.fetchTimeStamp(serverTimeNow / 1000 + '', '-'))
                        let serverTimeDateOne = new Date(this.fetchTimeStamp(serverTimeNow / 1000 + '', '/'))
                        serverTimeDate = Date.parse(serverTimeDate) || Date.parse(serverTimeDateOne)
                        if ((classTimeDate / 1000 - serverTimeDate / 1000) / 60 <= 30 && moment(day).isSame(today)) {
                            if(value.status == 0 || value.status == 1){
                                todayCourseTimeType = 1
                                todayCourseMin = 0
                                timeClassStart = 0
                                isFinishedClass = 0
                            }
                        }

                        if ((classTimeDate / 1000 - serverTimeDate / 1000) / 60 <= 5 && moment(day).isSame(today)) {
                            if(value.status == 0 || value.status == 1){
                                todayCourseTimeType = 1
                                todayCourseMin = 1
                                timeClassStart = 0
                                isFinishedClass = 0
                            }
                        }

                        if ((classTimeDate / 1000 - serverTimeDate / 1000) / 60 <= 0 && moment(day).isSame(today)) {
                            if(value.status == 0 || value.status == 1){
                                todayCourseTimeType = 1
                                todayCourseMin = 1
                                timeClassStart = 1
                                isFinishedClass = 0
                            }
                        }
                        if (serverTimeDate / 1000 >= courseEndAtTime / 1000 && value.status == 2) {
                            todayCourseTimeType = 1
                            todayCourseMin = 1
                            timeClassStart = 1
                            isFinishedClass = 1
                        }

                        let course = new RecordsModel(
                            classroomID,
                            courseID,
                            roomNum,
                            sdkType,
                            otherThirdRoomNum,
                            classroomPassword,
                            courseType,
                            timestamp,
                            teacherID,
                            teacherUserId,
                            teacherName,
                            pptID,
                            dynamicId,
                            coursewareName,
                            courseLong,
                            courseStatus,
                            pptType,
                            reportStatus,
                            homeWorkStatus,
                            todayCourseTimeType,
                            todayCourseMin,
                            timeClassStart,
                            isFinishedClass,
                            courseEndTime,
                            courseEndAtTime,
                            isCacheTime,
                        )
                        _allCourse.push(course)
                        console.log('allcourse',course)
                        if (courseStatus == 2) {
                            _finishedCourse.push(course)

                        } else if(courseStatus == 0 || courseStatus == 1){
                            if (moment(day).isSame(today)) {
                                _todayUnfinishedCourse.push(course)
                                _todayAllUnfinishedCourse.push(course)
                            }

                            _unfinishedCourse.push(course)

                        }
                    })

                    this.allCourse = [...this.allCourse, ..._allCourse]
                    this.finishedCourse = [...this.finishedCourse, ..._finishedCourse]
                    this.unfinishedCourse = [...this.unfinishedCourse, ..._unfinishedCourse]
                    console.log(this.unfinishedCourse.slice(), _unfinishedCourse, 'this.unfinishedCourse22222')
                    this.todayAllUnfinishedCourse = [...this.todayAllUnfinishedCourse, ..._todayAllUnfinishedCourse]
                    this.todayUnfinishedCourse = this.todayAllUnfinishedCourse

                    let nextPage = pageNum * pageSize < totalNum ? true : false

                    resolve({
                        nextPage
                    })
                })
                .catch(error => {
                    reject({
                        error: error
                    })
                })
        })
    }
    /**
     * @desc 单独根据课程类型请求列表
     * @param type runTime(进行中+未开始) finish(已完成)
     * */
    fetchCourseRecordsByType = (pageNum, pageSize, serverTimeNow, type) => {
      const getData = {
        pageNum: pageNum,
        pageSize: pageSize,
        type: type,
      }
      return new Promise((resolve, reject) => {
          NetStore.fetch(CzbApi.kFetchCourseRecords, null, getData)
              .then(response => {
                  // console.log(response, getData, 'fetchCourseRecordsByType-----');
                  const {code,msg,data} = response;
                  let result = data && data.result
                  if (!result) {
                    result = []
                  }
                  let _allCourse = []
                  // 按照上面的fetchCourseRecords内部格式化数据格式
                  result.map((value, index) => {

                      const {
                          roomId: classroomID,
                          arrangingId: courseID,
                          roomNum:roomNum,
                          otherThirdType: sdkType,
                          otherThirdRoomNum:otherThirdRoomNum,
                          talkerPass: classroomPassword,
                          classType: courseType,
                          bookTime: timestamp,
                          teacherId:teacherID,
                          teacherUserId:teacherUserId,
                          teacherName:teacherName,
                          coursewareId: pptID,
                          dynamicId:dynamicId,
                          coursewareName:coursewareName,
                          whenLong: courseLong,
                          status: courseStatus,
                          coursewareType: pptType, // 课件类型 1 静态 2 动态
                          reportStatus:reportStatus,
                          homeWorkStatus:homeWorkStatus,
                      } = value

                      let courseEndTime = (parseInt(value.whenLong) - 2) * 60 * 1000 + value.bookTime //课程真正结束时刻前2分钟即可认为课程结束
                      let courseEndAtTime = (parseInt(value.whenLong)) * 60 * 1000 + value.bookTime // 课程真正结束时间，用在首页刷新调用
                      let isCacheTime = value.bookTime + 3 * 60 * 60 * 1000 // 动态课件清理缓存时间 上课三小时之后清除

                      const day = moment(value.bookTime).format('YYYY-MM-DD')
                      const today = moment().format('YYYY-MM-DD')
                      let todayCourseTimeType = 0 // 是否为30分钟之内可进课程
                      let todayCourseMin = 0 // 判断是否是开课5分钟之内
                      let timeClassStart = 0 // 未开始上课
                      let isFinishedClass = 0 // 未结束上课
                      let classTimeDate = new Date(this.fetchTimeStamp(value.bookTime / 1000 + '', '-'))
                      let classTimeDateOne = new Date(this.fetchTimeStamp(value.bookTime / 1000 + '', '/'))
                      classTimeDate = Date.parse(classTimeDate) || Date.parse(classTimeDateOne)
                      let serverTimeDate = new Date(this.fetchTimeStamp(serverTimeNow / 1000 + '', '-'))
                      let serverTimeDateOne = new Date(this.fetchTimeStamp(serverTimeNow / 1000 + '', '/'))
                      serverTimeDate = Date.parse(serverTimeDate) || Date.parse(serverTimeDateOne)
                      if ((classTimeDate / 1000 - serverTimeDate / 1000) / 60 <= 30 && moment(day).isSame(today)) {
                          if(value.status == 0 || value.status == 1){
                              todayCourseTimeType = 1
                              todayCourseMin = 0
                              timeClassStart = 0
                              isFinishedClass = 0
                          }
                      }

                      if ((classTimeDate / 1000 - serverTimeDate / 1000) / 60 <= 5 && moment(day).isSame(today)) {
                          if(value.status == 0 || value.status == 1){
                              todayCourseTimeType = 1
                              todayCourseMin = 1
                              timeClassStart = 0
                              isFinishedClass = 0
                          }
                      }

                      if ((classTimeDate / 1000 - serverTimeDate / 1000) / 60 <= 0 && moment(day).isSame(today)) {
                          if(value.status == 0 || value.status == 1){
                              todayCourseTimeType = 1
                              todayCourseMin = 1
                              timeClassStart = 1
                              isFinishedClass = 0
                          }
                      }
                      if (serverTimeDate / 1000 >= courseEndAtTime / 1000 && value.status == 2) {
                          todayCourseTimeType = 1
                          todayCourseMin = 1
                          timeClassStart = 1
                          isFinishedClass = 1
                      }

                      let course = new RecordsModel(
                          classroomID,
                          courseID,
                          roomNum,
                          sdkType,
                          otherThirdRoomNum,
                          classroomPassword,
                          courseType,
                          timestamp,
                          teacherID,
                          teacherUserId,
                          teacherName,
                          pptID,
                          dynamicId,
                          coursewareName,
                          courseLong,
                          courseStatus,
                          pptType,
                          reportStatus,
                          homeWorkStatus,
                          todayCourseTimeType,
                          todayCourseMin,
                          timeClassStart,
                          isFinishedClass,
                          courseEndTime,
                          courseEndAtTime,
                          isCacheTime,
                      )
                      _allCourse.push(course)
                  })
                  console.log(_allCourse, result, type, 'fetchCourseRecordsByType');
                  if (code == 200) {
                    resolve(_allCourse)
                  }
              })
              .catch(error => {
                  reject(error);
              })
      })
    }

    /**
     * @desc 用于获取课程标签
     * @param bookedId 预约id
     * */
    @action
    fetchCourseTag = (bookedId) => {
        let url = CzbApi.kFetchCourseTag;
        let getData = {
            arrangingId: bookedId
        }
        return new Promise((resolve, reject) => {
            NetStore.fetch(url, null, getData)
                .then(response => {
                    const {code,msg,data} = response;
                    if(code == 200){
                        if(data){
                            this.tagResult = data;
                            resolve(response);
                        }
                    }else{
                        throw response;
                    }
                })
                .catch(error => {
                    this.tagResult = null
                    reject(error);
                })
        })
    }

}

export let RecordsStore = new Records
