import moment from 'moment'
import { observable, action } from 'mobx'
import { CzbApi, CzbCourseType } from '../model'
import { NetStore, UserStore } from '../store'

class ReportModel {

    teacherName = null
    time = null
    txt = null
    html = null
    upLoadStatus = null
    constructor(teacherName, time, txt, html,upLoadStatus) {
        this.teacherName = teacherName
        this.time = moment(time).format('YYYY-MM-DD HH:mm')
        this.txt = txt
        this.html = html
        this.upLoadStatus = upLoadStatus
    }
}

class Report {

    @observable report = null

    /**
     * 更新课后报告状态
     * @param roomId  预约课程的教室id（必传）
     * @param userId
     * @param reportType
     * */
    updateReportStateNew = (roomId,userId,reportType)=>{
        let url = CzbApi.UpdateReport;
        let getData = {
            roomId: roomId,
            userId: userId,
            reportType: reportType?reportType:1,//后台在这里要传个数据
        }
        return new Promise((resolve, reject) => {
            NetStore.fetch(url, null, getData)
                .then(response => {
                    resolve(response)
                })
                .catch(error => {
                    reject(error)
                })
        })
    }

    /**
     * 更新课后报告状态
     * */
    updateReportState = (bookedId,userId,reportType)=>{
        this.updateReportStateNew(bookedId,UserStore.id,reportType)
    }

    /**
     * 获取新的课后报告
     * @param roomId 教室id
     * @param courseType 课程类型
     * @param reportType 课后报告类型 0是一对一 1是一对多
     * */
    fetchReportNew = (roomId,courseType,typeReport)=>{
        let reportType = 0
        if(typeReport) { // 适配手机推送，传两个就是手机路由，传三个参数是手机推送
            reportType = typeReport
        }else {
            if (courseType == CzbCourseType.oto || courseType == CzbCourseType.otoExp) {//1V1
                reportType = 0
            }else if (courseType == CzbCourseType.otm || courseType == CzbCourseType.otmExp) {//1V6
                reportType = 1
            }
        }
        let url = CzbApi.GetReport;
        let getData = {
            roomId:roomId,
            userId:UserStore.id,
            reportType:reportType
        }
        console.log('fetchReportNew',getData);
        return new Promise((resolve, reject) => {
            NetStore.fetch(url, null, getData)
                .then(response => {
                    const {code,data} = response;
                    console.log('fetchReportNew',response);
                    if(code == 200){
                        const { BookedReportNew: teacherReport } = data;
                        if(teacherReport){
                            const { expertName, studentName:nickName, reportTime, reportTxt, report: reportHTML,upLoadStatus } = teacherReport
                            if(!reportTime){//上传状态为空的话
                                this.report = null;
                            }else {
                                this.report = new ReportModel(expertName, reportTime, reportTxt, reportHTML,upLoadStatus)
                            }
                            resolve(this.report)
                        }
                    }else{
                        this.report = null
                        throw response
                    }
                })
                .catch(error => {
                    this.report = null;
                    console.log('fetchReportNew',error);
                    reject(error)
                })
        })
    }

    /**
     * 获取课后报告
     * courseID 课程id （新接口要传入）roomId
     * courseType 课程类型
     * @memberof ReportStore
     */
    @action
    fetchReport = (courseID, courseType, typeReport) => {
        this.fetchReportNew(courseID,courseType,typeReport)
    }
}

export let ReportStore = new Report
