import { observable, action } from 'mobx'
import { CzbApi } from '../model'
import { NetStore, UserStore } from '../store'
import moment from 'moment'

const ShareText = {
    focus: {
        typeName:'focus',
        img: `${CzbApi.kImageUrl}/icon_share_green.png`,
        title: '【成长保趣学趣成长】我学习了专注力课程',
        content: '通过游戏式的训练提升孩子的专注力、情绪管理、 问题解决问题等，让孩子学会快速切换专注力，并能长时间专注学习，从源头预防孩子学习注意力不集中的问题。',
    },
    mathematical: {
        typeName:'mathematical',
        img: `${CzbApi.kImageUrl}/icon_share_red.png`,
        title: '成长保趣学趣成长】我学习了数理逻辑课程',
        content: '针对4-10岁孩子，培养孩子的数理逻辑提升和记忆学习的方法，激发孩子对理科的兴趣，为今后学习打下基础',
    },
    language: {
        typeName:'language',
        img: `${CzbApi.kImageUrl}/icon_share_orange.png`,
        title: '【成长保趣学趣成长】我学习了语言逻辑课程 ',
        content: '通过看图说故事、概括复述、口头表达等6大训练模块，引导孩子学习讲故事、组织语言、思考的方法等，全面培养孩子的阅读能力、表达能力和写作能力。',
    },
    experience: {
        typeName:'experience',
        img: `${CzbApi.kImageUrl}/icon_share_blue.png`,
        title: '【成长保趣学趣成长】我学习了体验训练课程',
        content: '通过有趣的在线互动直播课堂提供智能课件、交互游戏等互动学习体验，训练孩子的语言逻辑、数理逻辑、记忆力、专注力等能力，让孩子拥有独立思考的能力。',
    }
}

class Share {
    @observable showShareModal = false
    @observable serverTimeNow = null
    @observable shareCourseText = {}
    @observable type = null


    //目前区分四大类：专注力训练课，数理逻辑训练课，语言逻辑训练课，体验训练课。
    getShareContent = (courseName, firstName, secondName ,fieldId) => {
        let url = img = title = content = null
        if (courseName === "专注力训练课") {
            this.type = ShareText.focus
        }
        else if (courseName === "数理逻辑训练课") {
            this.type =  ShareText.mathematical
        }
        else if (courseName === "语言逻辑训练课") {
            this.type = ShareText.language
        }
        else if (courseName === "体验训练课") {
            this.type = ShareText.experience
        }

        if (this.type) {
            this.shareCourseText = {
                url: CzbApi.kCourseShare + `?fieldOne=${this.type.typeName}&fieldTwo=${secondName}&fieldOneId=${fieldId}&name=${courseName}&subClassificationName=${'课后分享'}`,
                img: this.type.img,
                title: this.type.title,
                content: this.type.content,
                //后两个参数埋点用
                courseName: courseName,
                secondName: secondName,
            }
            console.log('即将分享的内容：', this.shareCourseText)
        }
    }

    /**
     * 请求服务器时间
     */
    @action
    fetchServerTime = () => {
        let url = CzbApi.kFetchServerTime
        return new Promise((resolve, reject) => {
            NetStore.fetch(url, null).then(
                response => {
                    this.serverTimeNow = response.data
                    resolve()
                }
            ).catch(
                err => {
                    reject(err)
                }
            )
        })
    }

    // (所有分享统计接口)
    @action
    fetchVideoShareStatistics = (query) => {
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kVideoShareStatistics, query)
                .then(response => {
                    resolve(response)
                })
                .catch(error => {
                    reject(error)
                })
        })
    }
}

export let ShareStore = new Share()