import { CzbApi, User, CzbSocketType, CzbCourseType, CzbHost,SocketHost} from '../model'
import { UserStore } from './UserStore'
import { Store } from '../Store'
import io from 'socket.io-client'
import {InteractionStore} from './InteractionStore'
class Socket {

    socket
    courseID
    classroomID
    thirdID = 0

    type = CzbSocketType.oto //一对一正式课newclass 一对一体验课newClassExp 小班课smallclass 小班课体验课reservation

    _url = SocketHost
    _userType = 1 //student
    _role = 'student'

    setupSocket = (type, courseID, classroomID, uid ,role) => {
        if (type == CzbCourseType.oto) {
            this.type = CzbSocketType.oto
        }
        else if (type == CzbCourseType.otm) {
            this.type = CzbSocketType.otm
        }
        else if (type == CzbCourseType.otoExp) {
            this.type = CzbSocketType.otoExp
        }
        else if (type == CzbCourseType.otmExp) {
            this.type = CzbSocketType.otmExp

        }else if (type == CzbCourseType.otmAuditor) {
            this.type = CzbSocketType.otm // 添加旁听生（旁听生只添加在正式课）
        }

        if(role){
            this._role = role;
        }
        this.courseID = courseID
        this.classroomID = classroomID
        this.thirdID = uid
        if (!this._url) {
            throw Error('socket url is null')
        }
        if (!this.courseID) {
            throw Error('courseID is null')
        }
        if (!this.classroomID) {
            throw Error('classroomID is null')
        }
        let query = {
            token: UserStore.token,
            userType: this._userType,
            vsFrom: Store.vsFrom,
            role: this._role,
            type: this.type,
            id: UserStore.id,
            roomId: this.classroomID,
            courseId: this.courseID
        }
        let option = {
            query,
            timeout:3000
        }
        this.socket = io(this._url, option)
    }

    joinRoom = () => {
        let params = {
            name: UserStore.name,
            role: this._role,
            roomId: this.classroomID,
            avatar:UserStore.avatar
        }
        if (this.type == CzbSocketType.oto || this.type == CzbSocketType.otoExp) {
            params.swId = this.thirdID
        }

        this.emit('joinRoom', params)
        InteractionStore.isConnect = true
    }

    leaveRoom = () => {
        let params = {
            name: UserStore.name,
            role: this._role,
        }
        if (this.type == CzbSocketType.oto || this.type == CzbSocketType.otoExp) {
            params.swId = this.thirdID
        }
        this.emit('leaveRoom', params)
    }

    disconnect = () => {
        this.socket && this.socket.disconnect()
        InteractionStore.isConnect = false
    }

    close = ()=>{
        this.socket && this.socket.close();
    }

    getTeacher = () => {
        this.emit('getTeacher')
    }
    getStudents = () => {
        this.emit('getStudents')
    }
    getPPTIndex = () => {
        this.emit('getPPTIndex')
    }
    getLiveStatus = () => {
        this.emit('getLiveStatus')
    }
    getCanvasData = (targetIndex) => {
        this.emit('getCanvasData', { pptIndex: targetIndex })
    }

    getCanvasRender = () => {
        this.emit('canvasRender' , {type : "get"})
    }
    // 动态课件
  sendPPTData = (msg,cb) => {
    this.emit('cwMsg', {msg :msg}, ()=>{
        const ackInfo = JSON.stringify({
                cmd: 'ack',
                data: JSON.parse(msg)
            });
        InteractionStore.ackData = ackInfo;
        cb(InteractionStore.ackData);
    })
    }
    /**
     * 发送canvas数据
     * pptIndex 课件页码 int
     * height 画板高度 int
     * width 画板宽度 int
     * color 线条颜色 hex string
     * lineWidth 线条宽度 int
     * isErase 画线或橡皮擦 bool
     * points 点集 array
     *
     * @memberof SocketStore
     */
    sendCanvas = (pptIndex, height, width, color, lineWidth, isErase, points) => {
        this.emit('canvas',
            {
                pptIndex,
                canvasData:
                    {
                        canvasH: height,
                        canvasW: width,
                        color,
                        lineW: lineWidth,
                        data: points,
                        type: isErase ? 'eraser' : 'draw',
                    }
            })
    }
    clearCanvas = (pptIndex) => {
        this.emit('clearCanvas', { pptIndex })
    }
    raiseHand = () => {
        this.emit('raiseHand')
    }
    sendGameStartStatus = (gameID) => {
        this.emit('startGame', { gameStatus: 1, gameId: gameID })
    }
    sendGameEndStatus = (gameID, result) => {
        this.emit('endGame', { gameStatus: 2, gameId: gameID, name: UserStore.name, result })
    }
    publishCCStream = (streamID) => {
        this.emit('publishStream', { streamId: streamID, status: 1, role: 'student' })
    }
    publishAgoraOtm = (uid)=>{
        this.emit('publishStream', { streamId: uid, status: 1, role: 'student',senderId:UserStore.id })
    }
    publishTalkCloudOtm = (peerId)=>{
        this.emit('publishStream', {senderId:UserStore.id, streamId: peerId, status: 1, role: 'student' })
    }
    sendPingLog = (delay, loss, sessionId, classroomID ) => {
        this.emit('pingLog', {
            userId: UserStore.id,
            sessionId: sessionId ? sessionId : '',
            roomId: classroomID,
            delay,
            lossPercent: loss,
            device: Store.deviceInfo + '_' + Store.appVersion,
            role: this._role,
        })
    }

    /**
     * @desc 获取老师指定学生的状态
     * */
    getTeacherPointStudentStatus(){
        this.emit('soloShow',{
            "senderId": UserStore.id,
            "type": "get"
        });
    }

    emit = (eventType, data, ack) => {
        this.socket && this.socket.emit(eventType, { senderId: UserStore.id, ...data },ack)
    }
    registListener = (listener) => {
        for (let key in listener) {
            this.socket.on(key, event => listener[key]({ name: key, data: event }))
        }
    }

    getNetInfo = (delay, loss) => {
        const total_delay = delay + loss * 300
        if (total_delay >= 0 && total_delay < 100) {
            return 0
        }
        else if (total_delay >= 100 && total_delay < 400) {
            return 1
        }
        else if (total_delay >= 400) {
            return 2
        }
        return undefined
    }
}

export let SocketStore = new Socket
