import Storage from 'react-native-storage'
import { AsyncStorage } from 'react-native'
//引用数据存储组件(同步)
import Preference from 'react-native-preference';
class StorageManager {

    storage = new Storage({
        size: 1000,
        storageBackend: AsyncStorage,
        defaultExpires: null,
        enableCache: true,
    })

    save = (key, data) => {
        if (key && data != null) {
          this.storage.save({
            key: key,
            expires: null,
            data: data,
          })
        }
    }

    load = (key, sync, syncInBackground) => {
        var promise = new Promise((resolve, reject) => {
            this.storage.sync = sync
            this.storage.load({
                key: key,
                // autoSync(默认为true)意味着在没有找到数据或数据过期时自动调用相应的sync方法
                autoSync: true,
                // syncInBackground(默认为true)意味着如果数据过期，
                // 在调用sync方法的同时先返回已经过期的数据。
                // 设置为false的话，则始终强制返回sync方法提供的最新数据(当然会需要更多等待时间)。
                syncInBackground: syncInBackground,
            })
                .then(data => resolve(data))
                .catch(error => reject(error))
        })
        return promise
    }

    /**
     * 保存同步数据 (支持保存字符串和{}对象)
     * @param key
     * @param value
     * */
    saveSyncData = (key,value)=>{
        if(typeof value !== 'string'){//如果值不是字符时把对象转化成json对象
            value = JSON.stringify(value);
        }
        Preference.set(key, value);
    }

    /**
     * 读取同步数据
     * @param key
     * @return string
     * */
    readSyncData = (key)=>{
        return Preference.get(key)||'';
    }
}

export let StorageStore = new StorageManager
