import { observable, action, reaction } from 'mobx'
import { NetStore, StorageStore, HourStore, QuickStepStore, MessageStore, OrderStore } from '../store'
import { Store, Config } from '../Store'
import { CzbApi } from '../model'


class User {
    //个人信息
    @observable userInfo = null

    get id() {
        return this.userInfo ? this.userInfo.id : null
    }
    get tel() {
        return this.userInfo ? this.userInfo.tel : null
    }
    get token() {
        return this.userInfo ? this.userInfo.token : null
    }
    get avatar() {
        return this.userInfo ? this.userInfo.avatar : null
    }
    get grade() {
        return this.userInfo ? this.userInfo.grade : null
    }
    get name() {
        return this.userInfo ? this.userInfo.name : null
    }
    get gender() {
        return this.userInfo ? this.userInfo.gender : null
    }
    // get isBindedVideo() {
    //     return this.userInfo ? this.userInfo.isBindedVideo : null
    // }
    get vsFrom() {
        return this.userInfo ? this.userInfo.vsFrom : null
    }


    reaction = reaction(
        () => this.userInfo,
        (value, reaction) => {
            if (value) {
                StorageStore.save('userInfo', this.userInfo)
                OrderStore.fetchOrderList()
                HourStore.fetchCourseHour()
                QuickStepStore.fetchPromiseAllData()

                // MessageStore.fetchReservationMessage(1)
                // this.fetchIsBindedVideo()
            } else {
                HourStore.clear()
                OrderStore.clear()
                QuickStepStore.clear()
                MessageStore.clearMessage()
            }
        }
    )

    /**
     * 获取用户信息
     * return promise
     * @memberof UserStore
     */
    getUserInfo = () => {
      return new Promise((resolve, reject) => {
        NetStore.fetch(CzbApi.kGetUserInfo)
            .then(response => {
              console.log(response, 'getUserInfo----');
              const { schoolAge, gender, realName } = response.data
              UserStore.userInfo.grade = schoolAge
              UserStore.userInfo.gender = gender
              UserStore.userInfo.name = realName
              console.log(UserStore.userInfo);
              StorageStore.save('userInfo', this.userInfo)
              this.saveLoginState(true)
            })
            .catch(error => {
              this.saveLoginState(false)
            })
      })
    }
    /**
     * 从沙盒读取用户信息
     * return promise
     * @memberof UserStore
     */
    @action
    loadUserInfo = () => {
        return new Promise((resolve, reject) => {
            StorageStore.load('userInfo', () => {
            }, false)
                .then(response => {
                    // 若缓存中上次是三方登录，先改变vsFrom，再发生网络请求
                    const {vsFrom} = response
                    if (vsFrom) {
                        Store.vsFrom = vsFrom
                    }
                    this.userInfo = response
                    resolve(response)
                })
                .catch(error => {
                    reject(error)
                })
        })
    }

    /**
     * 修改用户资料
     * name：用户名
     * grade：孩子学年
     * gender: 孩子性别
     *
     * return promise
     * @memberof UserStore
     */
    @action
    reviseUserInfo = (name, grade, gender) => {
        let postData = {
            // nickname: name,
            // babyStage: grade,
            // type: 0,
            // gender,
            userId: UserStore.id,
            nickname: name,
            gender: gender,
            babyStage: grade,
        }
        return new Promise((resolve, reject) => {
            NetStore.fetch(CzbApi.kModifyUserInfo, postData)
                .then(response => {
                    console.log(response, this.userInfo, postData, CzbApi.kModifyUserInfo, 'reviseUserInfo=-=-=');
                    if (response.code == 200) {
                      let userInfo = this._deepClone(this.userInfo)
                      userInfo.name = name
                      userInfo.grade = grade
                      userInfo.gender = gender
                      this.userInfo = userInfo
                      resolve()
                    } else {
                      const error = response
                      error.errorMsg = response.msg
                      return reject(error)
                    }
                })
                .catch(error => {
                    reject(error)
                })
        })
    }

    /**
     * 修改用户头像
     * avatarUri：图片uri
     * return promise
     *
     * @memberof UserStore
     */
    @action
    reviseAvatar = (avatarUri) => {
        let id = this.userInfo.id
        return new Promise((resolve, reject) => {
            NetStore.uploadPicture(CzbApi.kModifyAvatar, id, avatarUri, 1)
                .then(response => {
                    // console.log(response, 'reviseAvatar--');
                    // const {result: newAvatarUrl} = response
                    let userInfo = this._deepClone(this.userInfo)
                    userInfo.avatar = response.data
                    this.userInfo = userInfo
                    resolve()
                })
                .catch(error => {
                    reject(error)
                })
        })
    }

    /**
     * 查询用户是否有赠送视频课程
     *
     * @memberof User
     */
    // fetchIsBindedVideo = () => {
    //     const query = {
    //         userId: this.userInfo.id
    //     }
    //     NetStore.fetch(CzbApi.kIsUserVideoBind, null, query)
    //         .then(response => {
    //             this.userInfo.isBindedVideo = true
    //         })
    //         .catch(error => {
    //             this.userInfo.isBindedVideo = false
    //         })
    // }

    _deepClone = (initalObj) => {
        var obj = {}
        try {
            obj = JSON.parse(JSON.stringify(initalObj))
        } catch ( error ) {
            return error
        }
        return obj
    }
}

export let UserStore = new User
