import { observable, action, computed } from 'mobx'
import { NetStore, UserStore } from '../store'
import { CzbApi } from '../model'

class VideoInfo {
  // @observable videoInfo = null

  @observable videoName = ''
  @observable videoUrl = ''
  @observable videoCover = ''
  @observable videoTags = []
  @observable videoIntroduction = ''
  @observable subClassificationId = ''

  @observable subClassificationName = ''
  @observable isCollect = 0
  @observable authorization = false
  @observable errorMsg = ''

  @observable videoCourseList = []

  // 精品课分类
  @observable chargeVideoClass = []
  // 相关视频数组
  @observable relateVideoList = []

  // 成长保视频分类
  @observable publicVideoClass = []

  @observable favoritesNeedRefresh = false

  // 视频用流量播放记住操作的全局变量(默认false)
  @observable useCellularNetWorkPlay = false
  // 获取免费视频详细信息
  @action
  fetchVideoInfo = (videoCourseId, userId) => {
    const query = {
      videoCourseId: videoCourseId,
      userId: userId,
    }
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kFetchVideoInfo, null, query)
        .then(response => {
          const data = response.data
          const {
            videoName,
            videoUrl,
            videoTags,
            videoIntroduction,
            subClassificationName,
            videoCover,
            subClassificationId,
            isCollect,
          } = data
          this.videoName = videoName
          this.videoUrl = videoUrl
          this.videoTags = videoTags
          this.videoCover = videoCover
          this.videoIntroduction = videoIntroduction
          this.subClassificationId = subClassificationId
          this.subClassificationName = subClassificationName
          this.isCollect = isCollect
          resolve()
        })
        .catch(error => {
          reject(error)
          this.errorMsg = error.errorMsg
        })
    })
  }

// 获取收费视频详细信息
  @action
  fetchChargeVideoInfo = (videoCourseId, userId) => {
    const query = {
      videoCourseId: videoCourseId,
      userId: userId,
    }
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kFetchChargeVideoInfo, null, query)
        .then(response => {
          // console.log(response, query, 'fetchChargeVideoInfo--=');
          const data = response.data
          const {
            videoName,
            videoUrl,
            videoTags,
            videoIntroduction,
            subClassificationName,
            videoCover,
            subClassificationId,
            isCollect,
            authorization,
          } = data
          this.videoName = videoName
          this.videoUrl = videoUrl
          this.videoTags = videoTags
          this.videoCover = videoCover
          this.videoIntroduction = videoIntroduction
          this.subClassificationId = subClassificationId
          this.subClassificationName = subClassificationName
          this.isCollect = isCollect
          this.authorization = authorization
          resolve()
        })
        .catch(error => {
          reject(error)
          this.errorMsg = error.errorMsg
        })
    })
  }

  // 获取分类下相关视频
  @action
  fetchRandomVideoBySubId = (subId, videoCourseId) => {
    const query = {
      subClassificationId: subId,
      videoCourseId: videoCourseId,
    }
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kFetchRandomVideoBySubId, null, query)
        .then(response => {
          const data = response.data
          this.relateVideoList = data
          resolve()
        })
        .catch(error => {
          reject(error)
        })
    })
  }
  // 获取精品课程分类
  @action
  fetchChargeVideoMainClassification = () => {
    return new Promise((resolve, reject) => {
      let getData = {
        userId: UserStore.id,
      }
      NetStore.fetch(CzbApi.kFetchVideoMainClassification, null, getData)
        .then(response => {
          // console.log(response, 'response-=-=-=-fetchChargeVideoMainClassification');
          this.chargeVideoClass = response.data
          resolve(response.data)
        })
        .catch(error => {
          // console.log(error, 'eroor0-0-0-0');
          reject(error)
        })
    })
  }



  // 获取主分类下的精品视频列表（无限列表）
  @action
  fetchVideoCourseListByMainId = (mainClassificationId, pageSize, pageNum) => {
    const query = {
      mainClassificationId: mainClassificationId,
      userId: UserStore.id,
      pageNum: pageNum,
      pageSize: pageSize
    }
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kFetchVideoCourseListByCondition, query)
        .then(response => {
          // console.log(response, query, 'fetchVideoCourseListByMainId-=-=');
          resolve(response.data)
        })
        .catch(error => {
          reject(error)
        })
    })
  }


  // 获取公开视频分类
  @action
  fetchPublicVideoClass = () => {
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kFetchPublicVideoClass, null)
          .then(response => {
            // console.log(response, 'fetchPublicVideoClass-=-');
              this.publicVideoClass = response.data
          })
          .catch(error => {
              // console.log(error, this, '====fetchPublicVideoClass');
              reject(error)
          })
    })
  }
  // 公开视频分类获取视频列表
  @action
  fetchVideoListBySubClassId = (subClassificationId, pageSize, pageNum) => {
    const query = {
      subClassificationId: subClassificationId,
      pageNum: pageNum,
      pageSize: pageSize
    }
    // console.log(query, '----');
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kFetchVideoListBySubClassId, query)
          .then(response => {
            console.log(response, query, 'fetchVideoListBySubClassId===');
            resolve(response)
          })
          .catch(error => {
              // console.log(error, '====');
              reject(error)
          })
    })
  }

  // 根据标签id获取拥有此标签的视频列表
  @action
  fetchVideoListLikeTag = (tagId, pageSize, pageNum) => {
    const query = {
      tagId: tagId,
      pageNum: pageNum,
      pageSize: pageSize
    }
    // console.log(query, '----');
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kFetchVideoListLikeTag, query)
          .then(response => {
            // console.log(response, 'response -------');
            resolve(response)
          })
          .catch(error => {
              // console.log(error, '====');
              reject(error)
          })
    })
  }

  // 用户点击视频标签统计
  @action
  fetchVideoTagStatistics = (app, platform, deviceId, userId, tagName, tagId, videoId) => {
    const query = {
      app: app,
      platform: platform,
      deviceId: deviceId,
      userId: userId,
      dataPoint: 'videoTag',
      data: {
        tagName: tagName,
        tagId: tagId,
        videoId: videoId
      }
    }
    // console.log(query, '----');
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kVideoTagStatistics, query)
          .then(response => {
            resolve(response)
          })
          .catch(error => {
              reject(error)
          })
    })
  }

  // 用户分享视频成功统计
  @action
  fetchVideoShareStatistics = (app, platform, deviceId, userId, videoId, sharedUrl, subClassificationName) => {
    const query = {
      app: app,
      platform: platform,
      deviceId: deviceId,
      userId: userId,
      dataPoint: 'appVideoShare',
      data: {
        videoId: videoId,
        sharedUrl: sharedUrl,
        subClassificationName: subClassificationName
      }
    }
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kVideoShareStatistics, query)
          .then(response => {
            resolve(response)
          })
          .catch(error => {
              reject(error)
          })
    })
  }

  // 收藏视频
  @action
  addVideoFavorite = (userId, videoCourseId) => {
    const query = {
      userId: userId,
      videoCourseId: videoCourseId,
      collectStatus: 0,
    }
    // console.log(query, '----');
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kAddVideoFavorite, query)
          .then(response => {
            console.log(response, query, JSON.stringify(query), 'addVideoFavorite -------');
            this.isCollect = 1
            this.favoritesNeedRefresh = true
            resolve(response)
          })
          .catch(error => {
              // console.log(error, '====');
              reject(error)
          })
    })
  }

  // 取消收藏视频
  @action
  cancelVideoFavorite = (userId, videoCourseId) => {
    const query = {
      userId: userId,
      videoCourseId: videoCourseId,
      collectStatus: 1,
    }
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kAddVideoFavorite, query)
          .then(response => {
            console.log(response, query, 'cancelVideoFavorite');
            this.isCollect = 0
            this.favoritesNeedRefresh = true
            resolve(response)
          })
          .catch(error => {
              reject(error)
          })
    })
  }

  // 根据用户id获取其收藏视频列表
  @action
  getVideoListByUserId = (userId, pageSize, pageNum) => {
    const query = {
      userId: userId,
      pageNum: pageNum,
      pageSize: pageSize,
    }
    return new Promise((resolve, reject) => {
      NetStore.fetch(CzbApi.kFetchVideoListByUserId, query)
          .then(response => {
            console.log(response, query, 'getVideoListByUserId');
            resolve(response)
          })
          .catch(error => {
              reject(error)
          })
          .finally(
            this.favoritesNeedRefresh = false
          )
    })
  }

}


export const VideoStore = new VideoInfo
